# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .instance_power_action_details import InstancePowerActionDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RebootMigrateActionDetails(InstancePowerActionDetails):
    """
    Parameters for the rebootMigrate :func:`instance_action`.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RebootMigrateActionDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.RebootMigrateActionDetails.action_type` attribute
        of this class is ``rebootMigrate`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action_type:
            The value to assign to the action_type property of this RebootMigrateActionDetails.
        :type action_type: str

        :param delete_local_storage:
            The value to assign to the delete_local_storage property of this RebootMigrateActionDetails.
        :type delete_local_storage: bool

        :param time_scheduled:
            The value to assign to the time_scheduled property of this RebootMigrateActionDetails.
        :type time_scheduled: datetime

        """
        self.swagger_types = {
            'action_type': 'str',
            'delete_local_storage': 'bool',
            'time_scheduled': 'datetime'
        }

        self.attribute_map = {
            'action_type': 'actionType',
            'delete_local_storage': 'deleteLocalStorage',
            'time_scheduled': 'timeScheduled'
        }

        self._action_type = None
        self._delete_local_storage = None
        self._time_scheduled = None
        self._action_type = 'rebootMigrate'

    @property
    def delete_local_storage(self):
        """
        Gets the delete_local_storage of this RebootMigrateActionDetails.
        For bare metal instances that have local storage, this must be set to true to verify that the local storage
        will be deleted during the migration.  For instances without, this parameter has no effect.


        :return: The delete_local_storage of this RebootMigrateActionDetails.
        :rtype: bool
        """
        return self._delete_local_storage

    @delete_local_storage.setter
    def delete_local_storage(self, delete_local_storage):
        """
        Sets the delete_local_storage of this RebootMigrateActionDetails.
        For bare metal instances that have local storage, this must be set to true to verify that the local storage
        will be deleted during the migration.  For instances without, this parameter has no effect.


        :param delete_local_storage: The delete_local_storage of this RebootMigrateActionDetails.
        :type: bool
        """
        self._delete_local_storage = delete_local_storage

    @property
    def time_scheduled(self):
        """
        Gets the time_scheduled of this RebootMigrateActionDetails.
        If present, this parameter will set (or re-set) the scheduled time that the instance will be reboot
        migrated in the format defined by `RFC3339`__.  This will also change
        the timeRebootMigrationDue field on the instance.
        If not present, the reboot migration will be triggered immediately.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_scheduled of this RebootMigrateActionDetails.
        :rtype: datetime
        """
        return self._time_scheduled

    @time_scheduled.setter
    def time_scheduled(self, time_scheduled):
        """
        Sets the time_scheduled of this RebootMigrateActionDetails.
        If present, this parameter will set (or re-set) the scheduled time that the instance will be reboot
        migrated in the format defined by `RFC3339`__.  This will also change
        the timeRebootMigrationDue field on the instance.
        If not present, the reboot migration will be triggered immediately.

        __ https://tools.ietf.org/html/rfc3339


        :param time_scheduled: The time_scheduled of this RebootMigrateActionDetails.
        :type: datetime
        """
        self._time_scheduled = time_scheduled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiffResponseEntry(object):
    """
    Entry for description of change on a file.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DiffResponseEntry object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param change_type:
            The value to assign to the change_type property of this DiffResponseEntry.
        :type change_type: str

        :param object_type:
            The value to assign to the object_type property of this DiffResponseEntry.
        :type object_type: str

        :param commit_id:
            The value to assign to the commit_id property of this DiffResponseEntry.
        :type commit_id: str

        :param old_path:
            The value to assign to the old_path property of this DiffResponseEntry.
        :type old_path: str

        :param new_path:
            The value to assign to the new_path property of this DiffResponseEntry.
        :type new_path: str

        :param old_id:
            The value to assign to the old_id property of this DiffResponseEntry.
        :type old_id: str

        :param new_id:
            The value to assign to the new_id property of this DiffResponseEntry.
        :type new_id: str

        :param url:
            The value to assign to the url property of this DiffResponseEntry.
        :type url: str

        :param added_lines_count:
            The value to assign to the added_lines_count property of this DiffResponseEntry.
        :type added_lines_count: int

        :param deleted_lines_count:
            The value to assign to the deleted_lines_count property of this DiffResponseEntry.
        :type deleted_lines_count: int

        :param are_conflicts_in_file:
            The value to assign to the are_conflicts_in_file property of this DiffResponseEntry.
        :type are_conflicts_in_file: bool

        """
        self.swagger_types = {
            'change_type': 'str',
            'object_type': 'str',
            'commit_id': 'str',
            'old_path': 'str',
            'new_path': 'str',
            'old_id': 'str',
            'new_id': 'str',
            'url': 'str',
            'added_lines_count': 'int',
            'deleted_lines_count': 'int',
            'are_conflicts_in_file': 'bool'
        }

        self.attribute_map = {
            'change_type': 'changeType',
            'object_type': 'objectType',
            'commit_id': 'commitId',
            'old_path': 'oldPath',
            'new_path': 'newPath',
            'old_id': 'oldId',
            'new_id': 'newId',
            'url': 'url',
            'added_lines_count': 'addedLinesCount',
            'deleted_lines_count': 'deletedLinesCount',
            'are_conflicts_in_file': 'areConflictsInFile'
        }

        self._change_type = None
        self._object_type = None
        self._commit_id = None
        self._old_path = None
        self._new_path = None
        self._old_id = None
        self._new_id = None
        self._url = None
        self._added_lines_count = None
        self._deleted_lines_count = None
        self._are_conflicts_in_file = None

    @property
    def change_type(self):
        """
        **[Required]** Gets the change_type of this DiffResponseEntry.
        Type of change made to file.


        :return: The change_type of this DiffResponseEntry.
        :rtype: str
        """
        return self._change_type

    @change_type.setter
    def change_type(self, change_type):
        """
        Sets the change_type of this DiffResponseEntry.
        Type of change made to file.


        :param change_type: The change_type of this DiffResponseEntry.
        :type: str
        """
        self._change_type = change_type

    @property
    def object_type(self):
        """
        Gets the object_type of this DiffResponseEntry.
        The type of the changed object.


        :return: The object_type of this DiffResponseEntry.
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """
        Sets the object_type of this DiffResponseEntry.
        The type of the changed object.


        :param object_type: The object_type of this DiffResponseEntry.
        :type: str
        """
        self._object_type = object_type

    @property
    def commit_id(self):
        """
        Gets the commit_id of this DiffResponseEntry.
        The ID of the commit where the change is coming from.


        :return: The commit_id of this DiffResponseEntry.
        :rtype: str
        """
        return self._commit_id

    @commit_id.setter
    def commit_id(self, commit_id):
        """
        Sets the commit_id of this DiffResponseEntry.
        The ID of the commit where the change is coming from.


        :param commit_id: The commit_id of this DiffResponseEntry.
        :type: str
        """
        self._commit_id = commit_id

    @property
    def old_path(self):
        """
        Gets the old_path of this DiffResponseEntry.
        The path on the target to the changed object.


        :return: The old_path of this DiffResponseEntry.
        :rtype: str
        """
        return self._old_path

    @old_path.setter
    def old_path(self, old_path):
        """
        Sets the old_path of this DiffResponseEntry.
        The path on the target to the changed object.


        :param old_path: The old_path of this DiffResponseEntry.
        :type: str
        """
        self._old_path = old_path

    @property
    def new_path(self):
        """
        Gets the new_path of this DiffResponseEntry.
        The path on the source to the changed object.


        :return: The new_path of this DiffResponseEntry.
        :rtype: str
        """
        return self._new_path

    @new_path.setter
    def new_path(self, new_path):
        """
        Sets the new_path of this DiffResponseEntry.
        The path on the source to the changed object.


        :param new_path: The new_path of this DiffResponseEntry.
        :type: str
        """
        self._new_path = new_path

    @property
    def old_id(self):
        """
        Gets the old_id of this DiffResponseEntry.
        The ID of the changed object on the target.


        :return: The old_id of this DiffResponseEntry.
        :rtype: str
        """
        return self._old_id

    @old_id.setter
    def old_id(self, old_id):
        """
        Sets the old_id of this DiffResponseEntry.
        The ID of the changed object on the target.


        :param old_id: The old_id of this DiffResponseEntry.
        :type: str
        """
        self._old_id = old_id

    @property
    def new_id(self):
        """
        Gets the new_id of this DiffResponseEntry.
        The ID of the changed object on the source.


        :return: The new_id of this DiffResponseEntry.
        :rtype: str
        """
        return self._new_id

    @new_id.setter
    def new_id(self, new_id):
        """
        Sets the new_id of this DiffResponseEntry.
        The ID of the changed object on the source.


        :param new_id: The new_id of this DiffResponseEntry.
        :type: str
        """
        self._new_id = new_id

    @property
    def url(self):
        """
        Gets the url of this DiffResponseEntry.
        The URL of the changed object.


        :return: The url of this DiffResponseEntry.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this DiffResponseEntry.
        The URL of the changed object.


        :param url: The url of this DiffResponseEntry.
        :type: str
        """
        self._url = url

    @property
    def added_lines_count(self):
        """
        Gets the added_lines_count of this DiffResponseEntry.
        The number of lines added in whole difference.


        :return: The added_lines_count of this DiffResponseEntry.
        :rtype: int
        """
        return self._added_lines_count

    @added_lines_count.setter
    def added_lines_count(self, added_lines_count):
        """
        Sets the added_lines_count of this DiffResponseEntry.
        The number of lines added in whole difference.


        :param added_lines_count: The added_lines_count of this DiffResponseEntry.
        :type: int
        """
        self._added_lines_count = added_lines_count

    @property
    def deleted_lines_count(self):
        """
        Gets the deleted_lines_count of this DiffResponseEntry.
        The number of lines deleted in whole difference.


        :return: The deleted_lines_count of this DiffResponseEntry.
        :rtype: int
        """
        return self._deleted_lines_count

    @deleted_lines_count.setter
    def deleted_lines_count(self, deleted_lines_count):
        """
        Sets the deleted_lines_count of this DiffResponseEntry.
        The number of lines deleted in whole difference.


        :param deleted_lines_count: The deleted_lines_count of this DiffResponseEntry.
        :type: int
        """
        self._deleted_lines_count = deleted_lines_count

    @property
    def are_conflicts_in_file(self):
        """
        Gets the are_conflicts_in_file of this DiffResponseEntry.
        Indicates whether the changed file contains conflicts.


        :return: The are_conflicts_in_file of this DiffResponseEntry.
        :rtype: bool
        """
        return self._are_conflicts_in_file

    @are_conflicts_in_file.setter
    def are_conflicts_in_file(self, are_conflicts_in_file):
        """
        Sets the are_conflicts_in_file of this DiffResponseEntry.
        Indicates whether the changed file contains conflicts.


        :param are_conflicts_in_file: The are_conflicts_in_file of this DiffResponseEntry.
        :type: bool
        """
        self._are_conflicts_in_file = are_conflicts_in_file

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Cluster(object):
    """
    A Kubernetes cluster. Avoid entering confidential information.
    """

    #: A constant which can be used with the lifecycle_state property of a Cluster.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Cluster.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Cluster.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Cluster.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Cluster.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Cluster.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    def __init__(self, **kwargs):
        """
        Initializes a new Cluster object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Cluster.
        :type id: str

        :param name:
            The value to assign to the name property of this Cluster.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Cluster.
        :type compartment_id: str

        :param endpoint_config:
            The value to assign to the endpoint_config property of this Cluster.
        :type endpoint_config: oci.container_engine.models.ClusterEndpointConfig

        :param vcn_id:
            The value to assign to the vcn_id property of this Cluster.
        :type vcn_id: str

        :param kubernetes_version:
            The value to assign to the kubernetes_version property of this Cluster.
        :type kubernetes_version: str

        :param kms_key_id:
            The value to assign to the kms_key_id property of this Cluster.
        :type kms_key_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Cluster.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Cluster.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this Cluster.
        :type system_tags: dict(str, dict(str, object))

        :param options:
            The value to assign to the options property of this Cluster.
        :type options: oci.container_engine.models.ClusterCreateOptions

        :param metadata:
            The value to assign to the metadata property of this Cluster.
        :type metadata: oci.container_engine.models.ClusterMetadata

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Cluster.
            Allowed values for this property are: "CREATING", "ACTIVE", "FAILED", "DELETING", "DELETED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this Cluster.
        :type lifecycle_details: str

        :param endpoints:
            The value to assign to the endpoints property of this Cluster.
        :type endpoints: oci.container_engine.models.ClusterEndpoints

        :param available_kubernetes_upgrades:
            The value to assign to the available_kubernetes_upgrades property of this Cluster.
        :type available_kubernetes_upgrades: list[str]

        :param image_policy_config:
            The value to assign to the image_policy_config property of this Cluster.
        :type image_policy_config: oci.container_engine.models.ImagePolicyConfig

        :param cluster_pod_network_options:
            The value to assign to the cluster_pod_network_options property of this Cluster.
        :type cluster_pod_network_options: list[oci.container_engine.models.ClusterPodNetworkOptionDetails]

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'compartment_id': 'str',
            'endpoint_config': 'ClusterEndpointConfig',
            'vcn_id': 'str',
            'kubernetes_version': 'str',
            'kms_key_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'options': 'ClusterCreateOptions',
            'metadata': 'ClusterMetadata',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'endpoints': 'ClusterEndpoints',
            'available_kubernetes_upgrades': 'list[str]',
            'image_policy_config': 'ImagePolicyConfig',
            'cluster_pod_network_options': 'list[ClusterPodNetworkOptionDetails]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'compartment_id': 'compartmentId',
            'endpoint_config': 'endpointConfig',
            'vcn_id': 'vcnId',
            'kubernetes_version': 'kubernetesVersion',
            'kms_key_id': 'kmsKeyId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'options': 'options',
            'metadata': 'metadata',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'endpoints': 'endpoints',
            'available_kubernetes_upgrades': 'availableKubernetesUpgrades',
            'image_policy_config': 'imagePolicyConfig',
            'cluster_pod_network_options': 'clusterPodNetworkOptions'
        }

        self._id = None
        self._name = None
        self._compartment_id = None
        self._endpoint_config = None
        self._vcn_id = None
        self._kubernetes_version = None
        self._kms_key_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._options = None
        self._metadata = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._endpoints = None
        self._available_kubernetes_upgrades = None
        self._image_policy_config = None
        self._cluster_pod_network_options = None

    @property
    def id(self):
        """
        Gets the id of this Cluster.
        The OCID of the cluster.


        :return: The id of this Cluster.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Cluster.
        The OCID of the cluster.


        :param id: The id of this Cluster.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Cluster.
        The name of the cluster.


        :return: The name of this Cluster.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Cluster.
        The name of the cluster.


        :param name: The name of this Cluster.
        :type: str
        """
        self._name = name

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this Cluster.
        The OCID of the compartment in which the cluster exists.


        :return: The compartment_id of this Cluster.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Cluster.
        The OCID of the compartment in which the cluster exists.


        :param compartment_id: The compartment_id of this Cluster.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def endpoint_config(self):
        """
        Gets the endpoint_config of this Cluster.
        The network configuration for access to the Cluster control plane.


        :return: The endpoint_config of this Cluster.
        :rtype: oci.container_engine.models.ClusterEndpointConfig
        """
        return self._endpoint_config

    @endpoint_config.setter
    def endpoint_config(self, endpoint_config):
        """
        Sets the endpoint_config of this Cluster.
        The network configuration for access to the Cluster control plane.


        :param endpoint_config: The endpoint_config of this Cluster.
        :type: oci.container_engine.models.ClusterEndpointConfig
        """
        self._endpoint_config = endpoint_config

    @property
    def vcn_id(self):
        """
        Gets the vcn_id of this Cluster.
        The OCID of the virtual cloud network (VCN) in which the cluster exists.


        :return: The vcn_id of this Cluster.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this Cluster.
        The OCID of the virtual cloud network (VCN) in which the cluster exists.


        :param vcn_id: The vcn_id of this Cluster.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def kubernetes_version(self):
        """
        Gets the kubernetes_version of this Cluster.
        The version of Kubernetes running on the cluster masters.


        :return: The kubernetes_version of this Cluster.
        :rtype: str
        """
        return self._kubernetes_version

    @kubernetes_version.setter
    def kubernetes_version(self, kubernetes_version):
        """
        Sets the kubernetes_version of this Cluster.
        The version of Kubernetes running on the cluster masters.


        :param kubernetes_version: The kubernetes_version of this Cluster.
        :type: str
        """
        self._kubernetes_version = kubernetes_version

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this Cluster.
        The OCID of the KMS key to be used as the master encryption key for Kubernetes secret encryption.


        :return: The kms_key_id of this Cluster.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this Cluster.
        The OCID of the KMS key to be used as the master encryption key for Kubernetes secret encryption.


        :param kms_key_id: The kms_key_id of this Cluster.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Cluster.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Cluster.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Cluster.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Cluster.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Cluster.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Cluster.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Cluster.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Cluster.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this Cluster.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this Cluster.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this Cluster.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this Cluster.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    @property
    def options(self):
        """
        Gets the options of this Cluster.
        Optional attributes for the cluster.


        :return: The options of this Cluster.
        :rtype: oci.container_engine.models.ClusterCreateOptions
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this Cluster.
        Optional attributes for the cluster.


        :param options: The options of this Cluster.
        :type: oci.container_engine.models.ClusterCreateOptions
        """
        self._options = options

    @property
    def metadata(self):
        """
        Gets the metadata of this Cluster.
        Metadata about the cluster.


        :return: The metadata of this Cluster.
        :rtype: oci.container_engine.models.ClusterMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this Cluster.
        Metadata about the cluster.


        :param metadata: The metadata of this Cluster.
        :type: oci.container_engine.models.ClusterMetadata
        """
        self._metadata = metadata

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Cluster.
        The state of the cluster masters.

        Allowed values for this property are: "CREATING", "ACTIVE", "FAILED", "DELETING", "DELETED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Cluster.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Cluster.
        The state of the cluster masters.


        :param lifecycle_state: The lifecycle_state of this Cluster.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "FAILED", "DELETING", "DELETED", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this Cluster.
        Details about the state of the cluster masters.


        :return: The lifecycle_details of this Cluster.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this Cluster.
        Details about the state of the cluster masters.


        :param lifecycle_details: The lifecycle_details of this Cluster.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def endpoints(self):
        """
        Gets the endpoints of this Cluster.
        Endpoints served up by the cluster masters.


        :return: The endpoints of this Cluster.
        :rtype: oci.container_engine.models.ClusterEndpoints
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """
        Sets the endpoints of this Cluster.
        Endpoints served up by the cluster masters.


        :param endpoints: The endpoints of this Cluster.
        :type: oci.container_engine.models.ClusterEndpoints
        """
        self._endpoints = endpoints

    @property
    def available_kubernetes_upgrades(self):
        """
        Gets the available_kubernetes_upgrades of this Cluster.
        Available Kubernetes versions to which the clusters masters may be upgraded.


        :return: The available_kubernetes_upgrades of this Cluster.
        :rtype: list[str]
        """
        return self._available_kubernetes_upgrades

    @available_kubernetes_upgrades.setter
    def available_kubernetes_upgrades(self, available_kubernetes_upgrades):
        """
        Sets the available_kubernetes_upgrades of this Cluster.
        Available Kubernetes versions to which the clusters masters may be upgraded.


        :param available_kubernetes_upgrades: The available_kubernetes_upgrades of this Cluster.
        :type: list[str]
        """
        self._available_kubernetes_upgrades = available_kubernetes_upgrades

    @property
    def image_policy_config(self):
        """
        Gets the image_policy_config of this Cluster.
        The image verification policy for signature validation.


        :return: The image_policy_config of this Cluster.
        :rtype: oci.container_engine.models.ImagePolicyConfig
        """
        return self._image_policy_config

    @image_policy_config.setter
    def image_policy_config(self, image_policy_config):
        """
        Sets the image_policy_config of this Cluster.
        The image verification policy for signature validation.


        :param image_policy_config: The image_policy_config of this Cluster.
        :type: oci.container_engine.models.ImagePolicyConfig
        """
        self._image_policy_config = image_policy_config

    @property
    def cluster_pod_network_options(self):
        """
        Gets the cluster_pod_network_options of this Cluster.
        Available CNIs and network options for existing and new node pools of the cluster


        :return: The cluster_pod_network_options of this Cluster.
        :rtype: list[oci.container_engine.models.ClusterPodNetworkOptionDetails]
        """
        return self._cluster_pod_network_options

    @cluster_pod_network_options.setter
    def cluster_pod_network_options(self, cluster_pod_network_options):
        """
        Sets the cluster_pod_network_options of this Cluster.
        Available CNIs and network options for existing and new node pools of the cluster


        :param cluster_pod_network_options: The cluster_pod_network_options of this Cluster.
        :type: list[oci.container_engine.models.ClusterPodNetworkOptionDetails]
        """
        self._cluster_pod_network_options = cluster_pod_network_options

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .absolute_wait_criteria import AbsoluteWaitCriteria
from .absolute_wait_criteria_summary import AbsoluteWaitCriteriaSummary
from .actual_build_runner_shape_config import ActualBuildRunnerShapeConfig
from .approval_action import ApprovalAction
from .approval_policy import ApprovalPolicy
from .approve_deployment_details import ApproveDeploymentDetails
from .automated_deploy_stage_rollback_policy import AutomatedDeployStageRollbackPolicy
from .backend_set_ip_collection import BackendSetIpCollection
from .bitbucket_cloud_app_password_connection import BitbucketCloudAppPasswordConnection
from .bitbucket_cloud_app_password_connection_summary import BitbucketCloudAppPasswordConnectionSummary
from .bitbucket_cloud_build_run_source import BitbucketCloudBuildRunSource
from .bitbucket_cloud_build_source import BitbucketCloudBuildSource
from .bitbucket_cloud_filter import BitbucketCloudFilter
from .bitbucket_cloud_filter_attributes import BitbucketCloudFilterAttributes
from .bitbucket_cloud_trigger import BitbucketCloudTrigger
from .bitbucket_cloud_trigger_create_result import BitbucketCloudTriggerCreateResult
from .bitbucket_cloud_trigger_summary import BitbucketCloudTriggerSummary
from .build_outputs import BuildOutputs
from .build_pipeline import BuildPipeline
from .build_pipeline_collection import BuildPipelineCollection
from .build_pipeline_parameter import BuildPipelineParameter
from .build_pipeline_parameter_collection import BuildPipelineParameterCollection
from .build_pipeline_stage import BuildPipelineStage
from .build_pipeline_stage_collection import BuildPipelineStageCollection
from .build_pipeline_stage_predecessor import BuildPipelineStagePredecessor
from .build_pipeline_stage_predecessor_collection import BuildPipelineStagePredecessorCollection
from .build_pipeline_stage_run_progress import BuildPipelineStageRunProgress
from .build_pipeline_stage_summary import BuildPipelineStageSummary
from .build_pipeline_summary import BuildPipelineSummary
from .build_run import BuildRun
from .build_run_argument import BuildRunArgument
from .build_run_argument_collection import BuildRunArgumentCollection
from .build_run_progress import BuildRunProgress
from .build_run_progress_summary import BuildRunProgressSummary
from .build_run_source import BuildRunSource
from .build_run_summary import BuildRunSummary
from .build_run_summary_collection import BuildRunSummaryCollection
from .build_source import BuildSource
from .build_source_collection import BuildSourceCollection
from .build_stage import BuildStage
from .build_stage_run_progress import BuildStageRunProgress
from .build_stage_run_step import BuildStageRunStep
from .build_stage_summary import BuildStageSummary
from .cancel_build_run_details import CancelBuildRunDetails
from .cancel_deployment_details import CancelDeploymentDetails
from .change_project_compartment_details import ChangeProjectCompartmentDetails
from .commit_info import CommitInfo
from .compute_instance_group_blue_green_deploy_stage import ComputeInstanceGroupBlueGreenDeployStage
from .compute_instance_group_blue_green_deploy_stage_execution_progress import ComputeInstanceGroupBlueGreenDeployStageExecutionProgress
from .compute_instance_group_blue_green_deploy_stage_summary import ComputeInstanceGroupBlueGreenDeployStageSummary
from .compute_instance_group_blue_green_traffic_shift_deploy_stage import ComputeInstanceGroupBlueGreenTrafficShiftDeployStage
from .compute_instance_group_blue_green_traffic_shift_deploy_stage_execution_progress import ComputeInstanceGroupBlueGreenTrafficShiftDeployStageExecutionProgress
from .compute_instance_group_blue_green_traffic_shift_deploy_stage_summary import ComputeInstanceGroupBlueGreenTrafficShiftDeployStageSummary
from .compute_instance_group_by_ids_selector import ComputeInstanceGroupByIdsSelector
from .compute_instance_group_by_query_selector import ComputeInstanceGroupByQuerySelector
from .compute_instance_group_canary_approval_deploy_stage import ComputeInstanceGroupCanaryApprovalDeployStage
from .compute_instance_group_canary_approval_deploy_stage_execution_progress import ComputeInstanceGroupCanaryApprovalDeployStageExecutionProgress
from .compute_instance_group_canary_approval_deploy_stage_summary import ComputeInstanceGroupCanaryApprovalDeployStageSummary
from .compute_instance_group_canary_deploy_stage import ComputeInstanceGroupCanaryDeployStage
from .compute_instance_group_canary_deploy_stage_execution_progress import ComputeInstanceGroupCanaryDeployStageExecutionProgress
from .compute_instance_group_canary_deploy_stage_summary import ComputeInstanceGroupCanaryDeployStageSummary
from .compute_instance_group_canary_traffic_shift_deploy_stage import ComputeInstanceGroupCanaryTrafficShiftDeployStage
from .compute_instance_group_canary_traffic_shift_deploy_stage_execution_progress import ComputeInstanceGroupCanaryTrafficShiftDeployStageExecutionProgress
from .compute_instance_group_canary_traffic_shift_deploy_stage_summary import ComputeInstanceGroupCanaryTrafficShiftDeployStageSummary
from .compute_instance_group_deploy_environment import ComputeInstanceGroupDeployEnvironment
from .compute_instance_group_deploy_environment_summary import ComputeInstanceGroupDeployEnvironmentSummary
from .compute_instance_group_deploy_stage import ComputeInstanceGroupDeployStage
from .compute_instance_group_deploy_stage_execution_progress import ComputeInstanceGroupDeployStageExecutionProgress
from .compute_instance_group_deploy_stage_summary import ComputeInstanceGroupDeployStageSummary
from .compute_instance_group_failure_policy import ComputeInstanceGroupFailurePolicy
from .compute_instance_group_failure_policy_by_count import ComputeInstanceGroupFailurePolicyByCount
from .compute_instance_group_failure_policy_by_percentage import ComputeInstanceGroupFailurePolicyByPercentage
from .compute_instance_group_linear_rollout_policy_by_count import ComputeInstanceGroupLinearRolloutPolicyByCount
from .compute_instance_group_linear_rollout_policy_by_percentage import ComputeInstanceGroupLinearRolloutPolicyByPercentage
from .compute_instance_group_rollout_policy import ComputeInstanceGroupRolloutPolicy
from .compute_instance_group_selector import ComputeInstanceGroupSelector
from .compute_instance_group_selector_collection import ComputeInstanceGroupSelectorCollection
from .connection import Connection
from .connection_collection import ConnectionCollection
from .connection_summary import ConnectionSummary
from .container_registry_delivered_artifact import ContainerRegistryDeliveredArtifact
from .count_based_approval_policy import CountBasedApprovalPolicy
from .create_absolute_wait_criteria_details import CreateAbsoluteWaitCriteriaDetails
from .create_bitbucket_cloud_app_password_connection_details import CreateBitbucketCloudAppPasswordConnectionDetails
from .create_bitbucket_cloud_trigger_details import CreateBitbucketCloudTriggerDetails
from .create_build_pipeline_details import CreateBuildPipelineDetails
from .create_build_pipeline_stage_details import CreateBuildPipelineStageDetails
from .create_build_run_details import CreateBuildRunDetails
from .create_build_stage_details import CreateBuildStageDetails
from .create_compute_instance_group_blue_green_deploy_stage_details import CreateComputeInstanceGroupBlueGreenDeployStageDetails
from .create_compute_instance_group_blue_green_traffic_shift_deploy_stage_details import CreateComputeInstanceGroupBlueGreenTrafficShiftDeployStageDetails
from .create_compute_instance_group_canary_approval_deploy_stage_details import CreateComputeInstanceGroupCanaryApprovalDeployStageDetails
from .create_compute_instance_group_canary_deploy_stage_details import CreateComputeInstanceGroupCanaryDeployStageDetails
from .create_compute_instance_group_canary_traffic_shift_deploy_stage_details import CreateComputeInstanceGroupCanaryTrafficShiftDeployStageDetails
from .create_compute_instance_group_deploy_environment_details import CreateComputeInstanceGroupDeployEnvironmentDetails
from .create_compute_instance_group_deploy_stage_details import CreateComputeInstanceGroupDeployStageDetails
from .create_connection_details import CreateConnectionDetails
from .create_deliver_artifact_stage_details import CreateDeliverArtifactStageDetails
from .create_deploy_artifact_details import CreateDeployArtifactDetails
from .create_deploy_environment_details import CreateDeployEnvironmentDetails
from .create_deploy_pipeline_deployment_details import CreateDeployPipelineDeploymentDetails
from .create_deploy_pipeline_details import CreateDeployPipelineDetails
from .create_deploy_pipeline_redeployment_details import CreateDeployPipelineRedeploymentDetails
from .create_deploy_stage_details import CreateDeployStageDetails
from .create_deployment_details import CreateDeploymentDetails
from .create_devops_code_repository_trigger_details import CreateDevopsCodeRepositoryTriggerDetails
from .create_function_deploy_environment_details import CreateFunctionDeployEnvironmentDetails
from .create_function_deploy_stage_details import CreateFunctionDeployStageDetails
from .create_github_access_token_connection_details import CreateGithubAccessTokenConnectionDetails
from .create_github_trigger_details import CreateGithubTriggerDetails
from .create_gitlab_access_token_connection_details import CreateGitlabAccessTokenConnectionDetails
from .create_gitlab_trigger_details import CreateGitlabTriggerDetails
from .create_invoke_function_deploy_stage_details import CreateInvokeFunctionDeployStageDetails
from .create_load_balancer_traffic_shift_deploy_stage_details import CreateLoadBalancerTrafficShiftDeployStageDetails
from .create_manual_approval_deploy_stage_details import CreateManualApprovalDeployStageDetails
from .create_oke_blue_green_deploy_stage_details import CreateOkeBlueGreenDeployStageDetails
from .create_oke_blue_green_traffic_shift_deploy_stage_details import CreateOkeBlueGreenTrafficShiftDeployStageDetails
from .create_oke_canary_approval_deploy_stage_details import CreateOkeCanaryApprovalDeployStageDetails
from .create_oke_canary_deploy_stage_details import CreateOkeCanaryDeployStageDetails
from .create_oke_canary_traffic_shift_deploy_stage_details import CreateOkeCanaryTrafficShiftDeployStageDetails
from .create_oke_cluster_deploy_environment_details import CreateOkeClusterDeployEnvironmentDetails
from .create_oke_deploy_stage_details import CreateOkeDeployStageDetails
from .create_oke_helm_chart_deploy_stage_details import CreateOkeHelmChartDeployStageDetails
from .create_project_details import CreateProjectDetails
from .create_repository_details import CreateRepositoryDetails
from .create_single_deploy_stage_deployment_details import CreateSingleDeployStageDeploymentDetails
from .create_single_deploy_stage_redeployment_details import CreateSingleDeployStageRedeploymentDetails
from .create_trigger_deployment_stage_details import CreateTriggerDeploymentStageDetails
from .create_trigger_details import CreateTriggerDetails
from .create_wait_criteria_details import CreateWaitCriteriaDetails
from .create_wait_deploy_stage_details import CreateWaitDeployStageDetails
from .create_wait_stage_details import CreateWaitStageDetails
from .deliver_artifact import DeliverArtifact
from .deliver_artifact_collection import DeliverArtifactCollection
from .deliver_artifact_stage import DeliverArtifactStage
from .deliver_artifact_stage_run_progress import DeliverArtifactStageRunProgress
from .deliver_artifact_stage_summary import DeliverArtifactStageSummary
from .delivered_artifact import DeliveredArtifact
from .delivered_artifact_collection import DeliveredArtifactCollection
from .deploy_artifact import DeployArtifact
from .deploy_artifact_collection import DeployArtifactCollection
from .deploy_artifact_override_argument import DeployArtifactOverrideArgument
from .deploy_artifact_override_argument_collection import DeployArtifactOverrideArgumentCollection
from .deploy_artifact_source import DeployArtifactSource
from .deploy_artifact_summary import DeployArtifactSummary
from .deploy_environment import DeployEnvironment
from .deploy_environment_collection import DeployEnvironmentCollection
from .deploy_environment_summary import DeployEnvironmentSummary
from .deploy_pipeline import DeployPipeline
from .deploy_pipeline_artifact import DeployPipelineArtifact
from .deploy_pipeline_artifact_collection import DeployPipelineArtifactCollection
from .deploy_pipeline_collection import DeployPipelineCollection
from .deploy_pipeline_deployment import DeployPipelineDeployment
from .deploy_pipeline_deployment_summary import DeployPipelineDeploymentSummary
from .deploy_pipeline_environment import DeployPipelineEnvironment
from .deploy_pipeline_environment_collection import DeployPipelineEnvironmentCollection
from .deploy_pipeline_parameter import DeployPipelineParameter
from .deploy_pipeline_parameter_collection import DeployPipelineParameterCollection
from .deploy_pipeline_redeployment import DeployPipelineRedeployment
from .deploy_pipeline_redeployment_summary import DeployPipelineRedeploymentSummary
from .deploy_pipeline_stage import DeployPipelineStage
from .deploy_pipeline_stage_collection import DeployPipelineStageCollection
from .deploy_pipeline_summary import DeployPipelineSummary
from .deploy_stage import DeployStage
from .deploy_stage_collection import DeployStageCollection
from .deploy_stage_execution_progress import DeployStageExecutionProgress
from .deploy_stage_execution_progress_details import DeployStageExecutionProgressDetails
from .deploy_stage_execution_step import DeployStageExecutionStep
from .deploy_stage_predecessor import DeployStagePredecessor
from .deploy_stage_predecessor_collection import DeployStagePredecessorCollection
from .deploy_stage_rollback_policy import DeployStageRollbackPolicy
from .deploy_stage_summary import DeployStageSummary
from .deployment import Deployment
from .deployment_argument import DeploymentArgument
from .deployment_argument_collection import DeploymentArgumentCollection
from .deployment_collection import DeploymentCollection
from .deployment_execution_progress import DeploymentExecutionProgress
from .deployment_summary import DeploymentSummary
from .devops_code_repository_build_run_source import DevopsCodeRepositoryBuildRunSource
from .devops_code_repository_build_source import DevopsCodeRepositoryBuildSource
from .devops_code_repository_filter import DevopsCodeRepositoryFilter
from .devops_code_repository_filter_attributes import DevopsCodeRepositoryFilterAttributes
from .devops_code_repository_trigger import DevopsCodeRepositoryTrigger
from .devops_code_repository_trigger_create_result import DevopsCodeRepositoryTriggerCreateResult
from .devops_code_repository_trigger_summary import DevopsCodeRepositoryTriggerSummary
from .diff_chunk import DiffChunk
from .diff_collection import DiffCollection
from .diff_line_details import DiffLineDetails
from .diff_response import DiffResponse
from .diff_response_entry import DiffResponseEntry
from .diff_section import DiffSection
from .diff_summary import DiffSummary
from .exported_variable import ExportedVariable
from .exported_variable_collection import ExportedVariableCollection
from .file_diff_response import FileDiffResponse
from .file_line_details import FileLineDetails
from .filter import Filter
from .function_deploy_environment import FunctionDeployEnvironment
from .function_deploy_environment_summary import FunctionDeployEnvironmentSummary
from .function_deploy_stage import FunctionDeployStage
from .function_deploy_stage_execution_progress import FunctionDeployStageExecutionProgress
from .function_deploy_stage_summary import FunctionDeployStageSummary
from .generic_delivered_artifact import GenericDeliveredArtifact
from .generic_deploy_artifact_source import GenericDeployArtifactSource
from .github_access_token_connection import GithubAccessTokenConnection
from .github_access_token_connection_summary import GithubAccessTokenConnectionSummary
from .github_build_run_source import GithubBuildRunSource
from .github_build_source import GithubBuildSource
from .github_filter import GithubFilter
from .github_filter_attributes import GithubFilterAttributes
from .github_trigger import GithubTrigger
from .github_trigger_create_result import GithubTriggerCreateResult
from .github_trigger_summary import GithubTriggerSummary
from .gitlab_access_token_connection import GitlabAccessTokenConnection
from .gitlab_access_token_connection_summary import GitlabAccessTokenConnectionSummary
from .gitlab_build_run_source import GitlabBuildRunSource
from .gitlab_build_source import GitlabBuildSource
from .gitlab_filter import GitlabFilter
from .gitlab_filter_attributes import GitlabFilterAttributes
from .gitlab_trigger import GitlabTrigger
from .gitlab_trigger_create_result import GitlabTriggerCreateResult
from .gitlab_trigger_summary import GitlabTriggerSummary
from .helm_repository_deploy_artifact_source import HelmRepositoryDeployArtifactSource
from .inline_deploy_artifact_source import InlineDeployArtifactSource
from .invoke_function_deploy_stage import InvokeFunctionDeployStage
from .invoke_function_deploy_stage_execution_progress import InvokeFunctionDeployStageExecutionProgress
from .invoke_function_deploy_stage_summary import InvokeFunctionDeployStageSummary
from .load_balancer_config import LoadBalancerConfig
from .load_balancer_traffic_shift_deploy_stage import LoadBalancerTrafficShiftDeployStage
from .load_balancer_traffic_shift_deploy_stage_execution_progress import LoadBalancerTrafficShiftDeployStageExecutionProgress
from .load_balancer_traffic_shift_deploy_stage_summary import LoadBalancerTrafficShiftDeployStageSummary
from .load_balancer_traffic_shift_rollout_policy import LoadBalancerTrafficShiftRolloutPolicy
from .manual_approval_deploy_stage import ManualApprovalDeployStage
from .manual_approval_deploy_stage_execution_progress import ManualApprovalDeployStageExecutionProgress
from .manual_approval_deploy_stage_summary import ManualApprovalDeployStageSummary
from .manual_build_run_source import ManualBuildRunSource
from .mirror_repository_config import MirrorRepositoryConfig
from .network_channel import NetworkChannel
from .nginx_blue_green_strategy import NginxBlueGreenStrategy
from .nginx_canary_strategy import NginxCanaryStrategy
from .no_deploy_stage_rollback_policy import NoDeployStageRollbackPolicy
from .notification_config import NotificationConfig
from .ocir_deploy_artifact_source import OcirDeployArtifactSource
from .oke_blue_green_deploy_stage import OkeBlueGreenDeployStage
from .oke_blue_green_deploy_stage_execution_progress import OkeBlueGreenDeployStageExecutionProgress
from .oke_blue_green_deploy_stage_summary import OkeBlueGreenDeployStageSummary
from .oke_blue_green_strategy import OkeBlueGreenStrategy
from .oke_blue_green_traffic_shift_deploy_stage import OkeBlueGreenTrafficShiftDeployStage
from .oke_blue_green_traffic_shift_deploy_stage_execution_progress import OkeBlueGreenTrafficShiftDeployStageExecutionProgress
from .oke_blue_green_traffic_shift_deploy_stage_summary import OkeBlueGreenTrafficShiftDeployStageSummary
from .oke_canary_approval_deploy_stage import OkeCanaryApprovalDeployStage
from .oke_canary_approval_deploy_stage_execution_progress import OkeCanaryApprovalDeployStageExecutionProgress
from .oke_canary_approval_deploy_stage_summary import OkeCanaryApprovalDeployStageSummary
from .oke_canary_deploy_stage import OkeCanaryDeployStage
from .oke_canary_deploy_stage_execution_progress import OkeCanaryDeployStageExecutionProgress
from .oke_canary_deploy_stage_summary import OkeCanaryDeployStageSummary
from .oke_canary_strategy import OkeCanaryStrategy
from .oke_canary_traffic_shift_deploy_stage import OkeCanaryTrafficShiftDeployStage
from .oke_canary_traffic_shift_deploy_stage_execution_progress import OkeCanaryTrafficShiftDeployStageExecutionProgress
from .oke_canary_traffic_shift_deploy_stage_summary import OkeCanaryTrafficShiftDeployStageSummary
from .oke_cluster_deploy_environment import OkeClusterDeployEnvironment
from .oke_cluster_deploy_environment_summary import OkeClusterDeployEnvironmentSummary
from .oke_deploy_stage import OkeDeployStage
from .oke_deploy_stage_execution_progress import OkeDeployStageExecutionProgress
from .oke_deploy_stage_summary import OkeDeployStageSummary
from .oke_helm_chart_deploy_stage import OkeHelmChartDeployStage
from .oke_helm_chart_deploy_stage_summary import OkeHelmChartDeployStageSummary
from .oke_helm_chart_deployment_stage_execution_progress import OkeHelmChartDeploymentStageExecutionProgress
from .private_endpoint_channel import PrivateEndpointChannel
from .project import Project
from .project_collection import ProjectCollection
from .project_summary import ProjectSummary
from .put_repository_branch_details import PutRepositoryBranchDetails
from .put_repository_ref_details import PutRepositoryRefDetails
from .put_repository_tag_details import PutRepositoryTagDetails
from .repository import Repository
from .repository_author_collection import RepositoryAuthorCollection
from .repository_author_summary import RepositoryAuthorSummary
from .repository_branch import RepositoryBranch
from .repository_branch_summary import RepositoryBranchSummary
from .repository_collection import RepositoryCollection
from .repository_commit import RepositoryCommit
from .repository_commit_collection import RepositoryCommitCollection
from .repository_commit_summary import RepositoryCommitSummary
from .repository_file_lines import RepositoryFileLines
from .repository_mirror_record import RepositoryMirrorRecord
from .repository_mirror_record_collection import RepositoryMirrorRecordCollection
from .repository_mirror_record_summary import RepositoryMirrorRecordSummary
from .repository_object import RepositoryObject
from .repository_path_collection import RepositoryPathCollection
from .repository_path_summary import RepositoryPathSummary
from .repository_ref import RepositoryRef
from .repository_ref_collection import RepositoryRefCollection
from .repository_ref_summary import RepositoryRefSummary
from .repository_summary import RepositorySummary
from .repository_tag import RepositoryTag
from .repository_tag_summary import RepositoryTagSummary
from .single_deploy_stage_deployment import SingleDeployStageDeployment
from .single_deploy_stage_deployment_summary import SingleDeployStageDeploymentSummary
from .single_deploy_stage_redeployment import SingleDeployStageRedeployment
from .single_deploy_stage_redeployment_summary import SingleDeployStageRedeploymentSummary
from .trigger import Trigger
from .trigger_action import TriggerAction
from .trigger_build_pipeline_action import TriggerBuildPipelineAction
from .trigger_collection import TriggerCollection
from .trigger_create_result import TriggerCreateResult
from .trigger_deployment_pipeline_stage_run_progress import TriggerDeploymentPipelineStageRunProgress
from .trigger_deployment_stage import TriggerDeploymentStage
from .trigger_deployment_stage_summary import TriggerDeploymentStageSummary
from .trigger_info import TriggerInfo
from .trigger_schedule import TriggerSchedule
from .trigger_summary import TriggerSummary
from .update_absolute_wait_criteria_details import UpdateAbsoluteWaitCriteriaDetails
from .update_bitbucket_cloud_app_password_connection_details import UpdateBitbucketCloudAppPasswordConnectionDetails
from .update_bitbucket_cloud_trigger_details import UpdateBitbucketCloudTriggerDetails
from .update_build_pipeline_details import UpdateBuildPipelineDetails
from .update_build_pipeline_stage_details import UpdateBuildPipelineStageDetails
from .update_build_run_details import UpdateBuildRunDetails
from .update_build_stage_details import UpdateBuildStageDetails
from .update_compute_instance_group_blue_green_deploy_stage_details import UpdateComputeInstanceGroupBlueGreenDeployStageDetails
from .update_compute_instance_group_blue_green_traffic_shift_deploy_stage_details import UpdateComputeInstanceGroupBlueGreenTrafficShiftDeployStageDetails
from .update_compute_instance_group_canary_approval_deploy_stage_details import UpdateComputeInstanceGroupCanaryApprovalDeployStageDetails
from .update_compute_instance_group_canary_deploy_stage_details import UpdateComputeInstanceGroupCanaryDeployStageDetails
from .update_compute_instance_group_canary_traffic_shift_deploy_stage_details import UpdateComputeInstanceGroupCanaryTrafficShiftDeployStageDetails
from .update_compute_instance_group_deploy_environment_details import UpdateComputeInstanceGroupDeployEnvironmentDetails
from .update_compute_instance_group_deploy_stage_details import UpdateComputeInstanceGroupDeployStageDetails
from .update_connection_details import UpdateConnectionDetails
from .update_deliver_artifact_stage_details import UpdateDeliverArtifactStageDetails
from .update_deploy_artifact_details import UpdateDeployArtifactDetails
from .update_deploy_environment_details import UpdateDeployEnvironmentDetails
from .update_deploy_pipeline_deployment_details import UpdateDeployPipelineDeploymentDetails
from .update_deploy_pipeline_details import UpdateDeployPipelineDetails
from .update_deploy_pipeline_redeployment_details import UpdateDeployPipelineRedeploymentDetails
from .update_deploy_stage_details import UpdateDeployStageDetails
from .update_deployment_details import UpdateDeploymentDetails
from .update_devops_code_repository_trigger_details import UpdateDevopsCodeRepositoryTriggerDetails
from .update_function_deploy_environment_details import UpdateFunctionDeployEnvironmentDetails
from .update_function_deploy_stage_details import UpdateFunctionDeployStageDetails
from .update_github_access_token_connection_details import UpdateGithubAccessTokenConnectionDetails
from .update_github_trigger_details import UpdateGithubTriggerDetails
from .update_gitlab_access_token_connection_details import UpdateGitlabAccessTokenConnectionDetails
from .update_gitlab_trigger_details import UpdateGitlabTriggerDetails
from .update_invoke_function_deploy_stage_details import UpdateInvokeFunctionDeployStageDetails
from .update_load_balancer_traffic_shift_deploy_stage_details import UpdateLoadBalancerTrafficShiftDeployStageDetails
from .update_manual_approval_deploy_stage_details import UpdateManualApprovalDeployStageDetails
from .update_oke_blue_green_deploy_stage_details import UpdateOkeBlueGreenDeployStageDetails
from .update_oke_blue_green_traffic_shift_deploy_stage_details import UpdateOkeBlueGreenTrafficShiftDeployStageDetails
from .update_oke_canary_approval_deploy_stage_details import UpdateOkeCanaryApprovalDeployStageDetails
from .update_oke_canary_deploy_stage_details import UpdateOkeCanaryDeployStageDetails
from .update_oke_canary_traffic_shift_deploy_stage_details import UpdateOkeCanaryTrafficShiftDeployStageDetails
from .update_oke_cluster_deploy_environment_details import UpdateOkeClusterDeployEnvironmentDetails
from .update_oke_deploy_stage_details import UpdateOkeDeployStageDetails
from .update_oke_helm_chart_deploy_stage_details import UpdateOkeHelmChartDeployStageDetails
from .update_project_details import UpdateProjectDetails
from .update_repository_details import UpdateRepositoryDetails
from .update_single_deploy_stage_deployment_details import UpdateSingleDeployStageDeploymentDetails
from .update_single_deploy_stage_redeployment_details import UpdateSingleDeployStageRedeploymentDetails
from .update_trigger_deployment_stage_details import UpdateTriggerDeploymentStageDetails
from .update_trigger_details import UpdateTriggerDetails
from .update_wait_criteria_details import UpdateWaitCriteriaDetails
from .update_wait_deploy_stage_details import UpdateWaitDeployStageDetails
from .update_wait_stage_details import UpdateWaitStageDetails
from .vulnerability_audit_summary import VulnerabilityAuditSummary
from .vulnerability_audit_summary_collection import VulnerabilityAuditSummaryCollection
from .wait_criteria import WaitCriteria
from .wait_criteria_summary import WaitCriteriaSummary
from .wait_deploy_stage import WaitDeployStage
from .wait_deploy_stage_execution_progress import WaitDeployStageExecutionProgress
from .wait_deploy_stage_summary import WaitDeployStageSummary
from .wait_stage import WaitStage
from .wait_stage_run_progress import WaitStageRunProgress
from .wait_stage_summary import WaitStageSummary
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for devops services.
devops_type_mapping = {
    "AbsoluteWaitCriteria": AbsoluteWaitCriteria,
    "AbsoluteWaitCriteriaSummary": AbsoluteWaitCriteriaSummary,
    "ActualBuildRunnerShapeConfig": ActualBuildRunnerShapeConfig,
    "ApprovalAction": ApprovalAction,
    "ApprovalPolicy": ApprovalPolicy,
    "ApproveDeploymentDetails": ApproveDeploymentDetails,
    "AutomatedDeployStageRollbackPolicy": AutomatedDeployStageRollbackPolicy,
    "BackendSetIpCollection": BackendSetIpCollection,
    "BitbucketCloudAppPasswordConnection": BitbucketCloudAppPasswordConnection,
    "BitbucketCloudAppPasswordConnectionSummary": BitbucketCloudAppPasswordConnectionSummary,
    "BitbucketCloudBuildRunSource": BitbucketCloudBuildRunSource,
    "BitbucketCloudBuildSource": BitbucketCloudBuildSource,
    "BitbucketCloudFilter": BitbucketCloudFilter,
    "BitbucketCloudFilterAttributes": BitbucketCloudFilterAttributes,
    "BitbucketCloudTrigger": BitbucketCloudTrigger,
    "BitbucketCloudTriggerCreateResult": BitbucketCloudTriggerCreateResult,
    "BitbucketCloudTriggerSummary": BitbucketCloudTriggerSummary,
    "BuildOutputs": BuildOutputs,
    "BuildPipeline": BuildPipeline,
    "BuildPipelineCollection": BuildPipelineCollection,
    "BuildPipelineParameter": BuildPipelineParameter,
    "BuildPipelineParameterCollection": BuildPipelineParameterCollection,
    "BuildPipelineStage": BuildPipelineStage,
    "BuildPipelineStageCollection": BuildPipelineStageCollection,
    "BuildPipelineStagePredecessor": BuildPipelineStagePredecessor,
    "BuildPipelineStagePredecessorCollection": BuildPipelineStagePredecessorCollection,
    "BuildPipelineStageRunProgress": BuildPipelineStageRunProgress,
    "BuildPipelineStageSummary": BuildPipelineStageSummary,
    "BuildPipelineSummary": BuildPipelineSummary,
    "BuildRun": BuildRun,
    "BuildRunArgument": BuildRunArgument,
    "BuildRunArgumentCollection": BuildRunArgumentCollection,
    "BuildRunProgress": BuildRunProgress,
    "BuildRunProgressSummary": BuildRunProgressSummary,
    "BuildRunSource": BuildRunSource,
    "BuildRunSummary": BuildRunSummary,
    "BuildRunSummaryCollection": BuildRunSummaryCollection,
    "BuildSource": BuildSource,
    "BuildSourceCollection": BuildSourceCollection,
    "BuildStage": BuildStage,
    "BuildStageRunProgress": BuildStageRunProgress,
    "BuildStageRunStep": BuildStageRunStep,
    "BuildStageSummary": BuildStageSummary,
    "CancelBuildRunDetails": CancelBuildRunDetails,
    "CancelDeploymentDetails": CancelDeploymentDetails,
    "ChangeProjectCompartmentDetails": ChangeProjectCompartmentDetails,
    "CommitInfo": CommitInfo,
    "ComputeInstanceGroupBlueGreenDeployStage": ComputeInstanceGroupBlueGreenDeployStage,
    "ComputeInstanceGroupBlueGreenDeployStageExecutionProgress": ComputeInstanceGroupBlueGreenDeployStageExecutionProgress,
    "ComputeInstanceGroupBlueGreenDeployStageSummary": ComputeInstanceGroupBlueGreenDeployStageSummary,
    "ComputeInstanceGroupBlueGreenTrafficShiftDeployStage": ComputeInstanceGroupBlueGreenTrafficShiftDeployStage,
    "ComputeInstanceGroupBlueGreenTrafficShiftDeployStageExecutionProgress": ComputeInstanceGroupBlueGreenTrafficShiftDeployStageExecutionProgress,
    "ComputeInstanceGroupBlueGreenTrafficShiftDeployStageSummary": ComputeInstanceGroupBlueGreenTrafficShiftDeployStageSummary,
    "ComputeInstanceGroupByIdsSelector": ComputeInstanceGroupByIdsSelector,
    "ComputeInstanceGroupByQuerySelector": ComputeInstanceGroupByQuerySelector,
    "ComputeInstanceGroupCanaryApprovalDeployStage": ComputeInstanceGroupCanaryApprovalDeployStage,
    "ComputeInstanceGroupCanaryApprovalDeployStageExecutionProgress": ComputeInstanceGroupCanaryApprovalDeployStageExecutionProgress,
    "ComputeInstanceGroupCanaryApprovalDeployStageSummary": ComputeInstanceGroupCanaryApprovalDeployStageSummary,
    "ComputeInstanceGroupCanaryDeployStage": ComputeInstanceGroupCanaryDeployStage,
    "ComputeInstanceGroupCanaryDeployStageExecutionProgress": ComputeInstanceGroupCanaryDeployStageExecutionProgress,
    "ComputeInstanceGroupCanaryDeployStageSummary": ComputeInstanceGroupCanaryDeployStageSummary,
    "ComputeInstanceGroupCanaryTrafficShiftDeployStage": ComputeInstanceGroupCanaryTrafficShiftDeployStage,
    "ComputeInstanceGroupCanaryTrafficShiftDeployStageExecutionProgress": ComputeInstanceGroupCanaryTrafficShiftDeployStageExecutionProgress,
    "ComputeInstanceGroupCanaryTrafficShiftDeployStageSummary": ComputeInstanceGroupCanaryTrafficShiftDeployStageSummary,
    "ComputeInstanceGroupDeployEnvironment": ComputeInstanceGroupDeployEnvironment,
    "ComputeInstanceGroupDeployEnvironmentSummary": ComputeInstanceGroupDeployEnvironmentSummary,
    "ComputeInstanceGroupDeployStage": ComputeInstanceGroupDeployStage,
    "ComputeInstanceGroupDeployStageExecutionProgress": ComputeInstanceGroupDeployStageExecutionProgress,
    "ComputeInstanceGroupDeployStageSummary": ComputeInstanceGroupDeployStageSummary,
    "ComputeInstanceGroupFailurePolicy": ComputeInstanceGroupFailurePolicy,
    "ComputeInstanceGroupFailurePolicyByCount": ComputeInstanceGroupFailurePolicyByCount,
    "ComputeInstanceGroupFailurePolicyByPercentage": ComputeInstanceGroupFailurePolicyByPercentage,
    "ComputeInstanceGroupLinearRolloutPolicyByCount": ComputeInstanceGroupLinearRolloutPolicyByCount,
    "ComputeInstanceGroupLinearRolloutPolicyByPercentage": ComputeInstanceGroupLinearRolloutPolicyByPercentage,
    "ComputeInstanceGroupRolloutPolicy": ComputeInstanceGroupRolloutPolicy,
    "ComputeInstanceGroupSelector": ComputeInstanceGroupSelector,
    "ComputeInstanceGroupSelectorCollection": ComputeInstanceGroupSelectorCollection,
    "Connection": Connection,
    "ConnectionCollection": ConnectionCollection,
    "ConnectionSummary": ConnectionSummary,
    "ContainerRegistryDeliveredArtifact": ContainerRegistryDeliveredArtifact,
    "CountBasedApprovalPolicy": CountBasedApprovalPolicy,
    "CreateAbsoluteWaitCriteriaDetails": CreateAbsoluteWaitCriteriaDetails,
    "CreateBitbucketCloudAppPasswordConnectionDetails": CreateBitbucketCloudAppPasswordConnectionDetails,
    "CreateBitbucketCloudTriggerDetails": CreateBitbucketCloudTriggerDetails,
    "CreateBuildPipelineDetails": CreateBuildPipelineDetails,
    "CreateBuildPipelineStageDetails": CreateBuildPipelineStageDetails,
    "CreateBuildRunDetails": CreateBuildRunDetails,
    "CreateBuildStageDetails": CreateBuildStageDetails,
    "CreateComputeInstanceGroupBlueGreenDeployStageDetails": CreateComputeInstanceGroupBlueGreenDeployStageDetails,
    "CreateComputeInstanceGroupBlueGreenTrafficShiftDeployStageDetails": CreateComputeInstanceGroupBlueGreenTrafficShiftDeployStageDetails,
    "CreateComputeInstanceGroupCanaryApprovalDeployStageDetails": CreateComputeInstanceGroupCanaryApprovalDeployStageDetails,
    "CreateComputeInstanceGroupCanaryDeployStageDetails": CreateComputeInstanceGroupCanaryDeployStageDetails,
    "CreateComputeInstanceGroupCanaryTrafficShiftDeployStageDetails": CreateComputeInstanceGroupCanaryTrafficShiftDeployStageDetails,
    "CreateComputeInstanceGroupDeployEnvironmentDetails": CreateComputeInstanceGroupDeployEnvironmentDetails,
    "CreateComputeInstanceGroupDeployStageDetails": CreateComputeInstanceGroupDeployStageDetails,
    "CreateConnectionDetails": CreateConnectionDetails,
    "CreateDeliverArtifactStageDetails": CreateDeliverArtifactStageDetails,
    "CreateDeployArtifactDetails": CreateDeployArtifactDetails,
    "CreateDeployEnvironmentDetails": CreateDeployEnvironmentDetails,
    "CreateDeployPipelineDeploymentDetails": CreateDeployPipelineDeploymentDetails,
    "CreateDeployPipelineDetails": CreateDeployPipelineDetails,
    "CreateDeployPipelineRedeploymentDetails": CreateDeployPipelineRedeploymentDetails,
    "CreateDeployStageDetails": CreateDeployStageDetails,
    "CreateDeploymentDetails": CreateDeploymentDetails,
    "CreateDevopsCodeRepositoryTriggerDetails": CreateDevopsCodeRepositoryTriggerDetails,
    "CreateFunctionDeployEnvironmentDetails": CreateFunctionDeployEnvironmentDetails,
    "CreateFunctionDeployStageDetails": CreateFunctionDeployStageDetails,
    "CreateGithubAccessTokenConnectionDetails": CreateGithubAccessTokenConnectionDetails,
    "CreateGithubTriggerDetails": CreateGithubTriggerDetails,
    "CreateGitlabAccessTokenConnectionDetails": CreateGitlabAccessTokenConnectionDetails,
    "CreateGitlabTriggerDetails": CreateGitlabTriggerDetails,
    "CreateInvokeFunctionDeployStageDetails": CreateInvokeFunctionDeployStageDetails,
    "CreateLoadBalancerTrafficShiftDeployStageDetails": CreateLoadBalancerTrafficShiftDeployStageDetails,
    "CreateManualApprovalDeployStageDetails": CreateManualApprovalDeployStageDetails,
    "CreateOkeBlueGreenDeployStageDetails": CreateOkeBlueGreenDeployStageDetails,
    "CreateOkeBlueGreenTrafficShiftDeployStageDetails": CreateOkeBlueGreenTrafficShiftDeployStageDetails,
    "CreateOkeCanaryApprovalDeployStageDetails": CreateOkeCanaryApprovalDeployStageDetails,
    "CreateOkeCanaryDeployStageDetails": CreateOkeCanaryDeployStageDetails,
    "CreateOkeCanaryTrafficShiftDeployStageDetails": CreateOkeCanaryTrafficShiftDeployStageDetails,
    "CreateOkeClusterDeployEnvironmentDetails": CreateOkeClusterDeployEnvironmentDetails,
    "CreateOkeDeployStageDetails": CreateOkeDeployStageDetails,
    "CreateOkeHelmChartDeployStageDetails": CreateOkeHelmChartDeployStageDetails,
    "CreateProjectDetails": CreateProjectDetails,
    "CreateRepositoryDetails": CreateRepositoryDetails,
    "CreateSingleDeployStageDeploymentDetails": CreateSingleDeployStageDeploymentDetails,
    "CreateSingleDeployStageRedeploymentDetails": CreateSingleDeployStageRedeploymentDetails,
    "CreateTriggerDeploymentStageDetails": CreateTriggerDeploymentStageDetails,
    "CreateTriggerDetails": CreateTriggerDetails,
    "CreateWaitCriteriaDetails": CreateWaitCriteriaDetails,
    "CreateWaitDeployStageDetails": CreateWaitDeployStageDetails,
    "CreateWaitStageDetails": CreateWaitStageDetails,
    "DeliverArtifact": DeliverArtifact,
    "DeliverArtifactCollection": DeliverArtifactCollection,
    "DeliverArtifactStage": DeliverArtifactStage,
    "DeliverArtifactStageRunProgress": DeliverArtifactStageRunProgress,
    "DeliverArtifactStageSummary": DeliverArtifactStageSummary,
    "DeliveredArtifact": DeliveredArtifact,
    "DeliveredArtifactCollection": DeliveredArtifactCollection,
    "DeployArtifact": DeployArtifact,
    "DeployArtifactCollection": DeployArtifactCollection,
    "DeployArtifactOverrideArgument": DeployArtifactOverrideArgument,
    "DeployArtifactOverrideArgumentCollection": DeployArtifactOverrideArgumentCollection,
    "DeployArtifactSource": DeployArtifactSource,
    "DeployArtifactSummary": DeployArtifactSummary,
    "DeployEnvironment": DeployEnvironment,
    "DeployEnvironmentCollection": DeployEnvironmentCollection,
    "DeployEnvironmentSummary": DeployEnvironmentSummary,
    "DeployPipeline": DeployPipeline,
    "DeployPipelineArtifact": DeployPipelineArtifact,
    "DeployPipelineArtifactCollection": DeployPipelineArtifactCollection,
    "DeployPipelineCollection": DeployPipelineCollection,
    "DeployPipelineDeployment": DeployPipelineDeployment,
    "DeployPipelineDeploymentSummary": DeployPipelineDeploymentSummary,
    "DeployPipelineEnvironment": DeployPipelineEnvironment,
    "DeployPipelineEnvironmentCollection": DeployPipelineEnvironmentCollection,
    "DeployPipelineParameter": DeployPipelineParameter,
    "DeployPipelineParameterCollection": DeployPipelineParameterCollection,
    "DeployPipelineRedeployment": DeployPipelineRedeployment,
    "DeployPipelineRedeploymentSummary": DeployPipelineRedeploymentSummary,
    "DeployPipelineStage": DeployPipelineStage,
    "DeployPipelineStageCollection": DeployPipelineStageCollection,
    "DeployPipelineSummary": DeployPipelineSummary,
    "DeployStage": DeployStage,
    "DeployStageCollection": DeployStageCollection,
    "DeployStageExecutionProgress": DeployStageExecutionProgress,
    "DeployStageExecutionProgressDetails": DeployStageExecutionProgressDetails,
    "DeployStageExecutionStep": DeployStageExecutionStep,
    "DeployStagePredecessor": DeployStagePredecessor,
    "DeployStagePredecessorCollection": DeployStagePredecessorCollection,
    "DeployStageRollbackPolicy": DeployStageRollbackPolicy,
    "DeployStageSummary": DeployStageSummary,
    "Deployment": Deployment,
    "DeploymentArgument": DeploymentArgument,
    "DeploymentArgumentCollection": DeploymentArgumentCollection,
    "DeploymentCollection": DeploymentCollection,
    "DeploymentExecutionProgress": DeploymentExecutionProgress,
    "DeploymentSummary": DeploymentSummary,
    "DevopsCodeRepositoryBuildRunSource": DevopsCodeRepositoryBuildRunSource,
    "DevopsCodeRepositoryBuildSource": DevopsCodeRepositoryBuildSource,
    "DevopsCodeRepositoryFilter": DevopsCodeRepositoryFilter,
    "DevopsCodeRepositoryFilterAttributes": DevopsCodeRepositoryFilterAttributes,
    "DevopsCodeRepositoryTrigger": DevopsCodeRepositoryTrigger,
    "DevopsCodeRepositoryTriggerCreateResult": DevopsCodeRepositoryTriggerCreateResult,
    "DevopsCodeRepositoryTriggerSummary": DevopsCodeRepositoryTriggerSummary,
    "DiffChunk": DiffChunk,
    "DiffCollection": DiffCollection,
    "DiffLineDetails": DiffLineDetails,
    "DiffResponse": DiffResponse,
    "DiffResponseEntry": DiffResponseEntry,
    "DiffSection": DiffSection,
    "DiffSummary": DiffSummary,
    "ExportedVariable": ExportedVariable,
    "ExportedVariableCollection": ExportedVariableCollection,
    "FileDiffResponse": FileDiffResponse,
    "FileLineDetails": FileLineDetails,
    "Filter": Filter,
    "FunctionDeployEnvironment": FunctionDeployEnvironment,
    "FunctionDeployEnvironmentSummary": FunctionDeployEnvironmentSummary,
    "FunctionDeployStage": FunctionDeployStage,
    "FunctionDeployStageExecutionProgress": FunctionDeployStageExecutionProgress,
    "FunctionDeployStageSummary": FunctionDeployStageSummary,
    "GenericDeliveredArtifact": GenericDeliveredArtifact,
    "GenericDeployArtifactSource": GenericDeployArtifactSource,
    "GithubAccessTokenConnection": GithubAccessTokenConnection,
    "GithubAccessTokenConnectionSummary": GithubAccessTokenConnectionSummary,
    "GithubBuildRunSource": GithubBuildRunSource,
    "GithubBuildSource": GithubBuildSource,
    "GithubFilter": GithubFilter,
    "GithubFilterAttributes": GithubFilterAttributes,
    "GithubTrigger": GithubTrigger,
    "GithubTriggerCreateResult": GithubTriggerCreateResult,
    "GithubTriggerSummary": GithubTriggerSummary,
    "GitlabAccessTokenConnection": GitlabAccessTokenConnection,
    "GitlabAccessTokenConnectionSummary": GitlabAccessTokenConnectionSummary,
    "GitlabBuildRunSource": GitlabBuildRunSource,
    "GitlabBuildSource": GitlabBuildSource,
    "GitlabFilter": GitlabFilter,
    "GitlabFilterAttributes": GitlabFilterAttributes,
    "GitlabTrigger": GitlabTrigger,
    "GitlabTriggerCreateResult": GitlabTriggerCreateResult,
    "GitlabTriggerSummary": GitlabTriggerSummary,
    "HelmRepositoryDeployArtifactSource": HelmRepositoryDeployArtifactSource,
    "InlineDeployArtifactSource": InlineDeployArtifactSource,
    "InvokeFunctionDeployStage": InvokeFunctionDeployStage,
    "InvokeFunctionDeployStageExecutionProgress": InvokeFunctionDeployStageExecutionProgress,
    "InvokeFunctionDeployStageSummary": InvokeFunctionDeployStageSummary,
    "LoadBalancerConfig": LoadBalancerConfig,
    "LoadBalancerTrafficShiftDeployStage": LoadBalancerTrafficShiftDeployStage,
    "LoadBalancerTrafficShiftDeployStageExecutionProgress": LoadBalancerTrafficShiftDeployStageExecutionProgress,
    "LoadBalancerTrafficShiftDeployStageSummary": LoadBalancerTrafficShiftDeployStageSummary,
    "LoadBalancerTrafficShiftRolloutPolicy": LoadBalancerTrafficShiftRolloutPolicy,
    "ManualApprovalDeployStage": ManualApprovalDeployStage,
    "ManualApprovalDeployStageExecutionProgress": ManualApprovalDeployStageExecutionProgress,
    "ManualApprovalDeployStageSummary": ManualApprovalDeployStageSummary,
    "ManualBuildRunSource": ManualBuildRunSource,
    "MirrorRepositoryConfig": MirrorRepositoryConfig,
    "NetworkChannel": NetworkChannel,
    "NginxBlueGreenStrategy": NginxBlueGreenStrategy,
    "NginxCanaryStrategy": NginxCanaryStrategy,
    "NoDeployStageRollbackPolicy": NoDeployStageRollbackPolicy,
    "NotificationConfig": NotificationConfig,
    "OcirDeployArtifactSource": OcirDeployArtifactSource,
    "OkeBlueGreenDeployStage": OkeBlueGreenDeployStage,
    "OkeBlueGreenDeployStageExecutionProgress": OkeBlueGreenDeployStageExecutionProgress,
    "OkeBlueGreenDeployStageSummary": OkeBlueGreenDeployStageSummary,
    "OkeBlueGreenStrategy": OkeBlueGreenStrategy,
    "OkeBlueGreenTrafficShiftDeployStage": OkeBlueGreenTrafficShiftDeployStage,
    "OkeBlueGreenTrafficShiftDeployStageExecutionProgress": OkeBlueGreenTrafficShiftDeployStageExecutionProgress,
    "OkeBlueGreenTrafficShiftDeployStageSummary": OkeBlueGreenTrafficShiftDeployStageSummary,
    "OkeCanaryApprovalDeployStage": OkeCanaryApprovalDeployStage,
    "OkeCanaryApprovalDeployStageExecutionProgress": OkeCanaryApprovalDeployStageExecutionProgress,
    "OkeCanaryApprovalDeployStageSummary": OkeCanaryApprovalDeployStageSummary,
    "OkeCanaryDeployStage": OkeCanaryDeployStage,
    "OkeCanaryDeployStageExecutionProgress": OkeCanaryDeployStageExecutionProgress,
    "OkeCanaryDeployStageSummary": OkeCanaryDeployStageSummary,
    "OkeCanaryStrategy": OkeCanaryStrategy,
    "OkeCanaryTrafficShiftDeployStage": OkeCanaryTrafficShiftDeployStage,
    "OkeCanaryTrafficShiftDeployStageExecutionProgress": OkeCanaryTrafficShiftDeployStageExecutionProgress,
    "OkeCanaryTrafficShiftDeployStageSummary": OkeCanaryTrafficShiftDeployStageSummary,
    "OkeClusterDeployEnvironment": OkeClusterDeployEnvironment,
    "OkeClusterDeployEnvironmentSummary": OkeClusterDeployEnvironmentSummary,
    "OkeDeployStage": OkeDeployStage,
    "OkeDeployStageExecutionProgress": OkeDeployStageExecutionProgress,
    "OkeDeployStageSummary": OkeDeployStageSummary,
    "OkeHelmChartDeployStage": OkeHelmChartDeployStage,
    "OkeHelmChartDeployStageSummary": OkeHelmChartDeployStageSummary,
    "OkeHelmChartDeploymentStageExecutionProgress": OkeHelmChartDeploymentStageExecutionProgress,
    "PrivateEndpointChannel": PrivateEndpointChannel,
    "Project": Project,
    "ProjectCollection": ProjectCollection,
    "ProjectSummary": ProjectSummary,
    "PutRepositoryBranchDetails": PutRepositoryBranchDetails,
    "PutRepositoryRefDetails": PutRepositoryRefDetails,
    "PutRepositoryTagDetails": PutRepositoryTagDetails,
    "Repository": Repository,
    "RepositoryAuthorCollection": RepositoryAuthorCollection,
    "RepositoryAuthorSummary": RepositoryAuthorSummary,
    "RepositoryBranch": RepositoryBranch,
    "RepositoryBranchSummary": RepositoryBranchSummary,
    "RepositoryCollection": RepositoryCollection,
    "RepositoryCommit": RepositoryCommit,
    "RepositoryCommitCollection": RepositoryCommitCollection,
    "RepositoryCommitSummary": RepositoryCommitSummary,
    "RepositoryFileLines": RepositoryFileLines,
    "RepositoryMirrorRecord": RepositoryMirrorRecord,
    "RepositoryMirrorRecordCollection": RepositoryMirrorRecordCollection,
    "RepositoryMirrorRecordSummary": RepositoryMirrorRecordSummary,
    "RepositoryObject": RepositoryObject,
    "RepositoryPathCollection": RepositoryPathCollection,
    "RepositoryPathSummary": RepositoryPathSummary,
    "RepositoryRef": RepositoryRef,
    "RepositoryRefCollection": RepositoryRefCollection,
    "RepositoryRefSummary": RepositoryRefSummary,
    "RepositorySummary": RepositorySummary,
    "RepositoryTag": RepositoryTag,
    "RepositoryTagSummary": RepositoryTagSummary,
    "SingleDeployStageDeployment": SingleDeployStageDeployment,
    "SingleDeployStageDeploymentSummary": SingleDeployStageDeploymentSummary,
    "SingleDeployStageRedeployment": SingleDeployStageRedeployment,
    "SingleDeployStageRedeploymentSummary": SingleDeployStageRedeploymentSummary,
    "Trigger": Trigger,
    "TriggerAction": TriggerAction,
    "TriggerBuildPipelineAction": TriggerBuildPipelineAction,
    "TriggerCollection": TriggerCollection,
    "TriggerCreateResult": TriggerCreateResult,
    "TriggerDeploymentPipelineStageRunProgress": TriggerDeploymentPipelineStageRunProgress,
    "TriggerDeploymentStage": TriggerDeploymentStage,
    "TriggerDeploymentStageSummary": TriggerDeploymentStageSummary,
    "TriggerInfo": TriggerInfo,
    "TriggerSchedule": TriggerSchedule,
    "TriggerSummary": TriggerSummary,
    "UpdateAbsoluteWaitCriteriaDetails": UpdateAbsoluteWaitCriteriaDetails,
    "UpdateBitbucketCloudAppPasswordConnectionDetails": UpdateBitbucketCloudAppPasswordConnectionDetails,
    "UpdateBitbucketCloudTriggerDetails": UpdateBitbucketCloudTriggerDetails,
    "UpdateBuildPipelineDetails": UpdateBuildPipelineDetails,
    "UpdateBuildPipelineStageDetails": UpdateBuildPipelineStageDetails,
    "UpdateBuildRunDetails": UpdateBuildRunDetails,
    "UpdateBuildStageDetails": UpdateBuildStageDetails,
    "UpdateComputeInstanceGroupBlueGreenDeployStageDetails": UpdateComputeInstanceGroupBlueGreenDeployStageDetails,
    "UpdateComputeInstanceGroupBlueGreenTrafficShiftDeployStageDetails": UpdateComputeInstanceGroupBlueGreenTrafficShiftDeployStageDetails,
    "UpdateComputeInstanceGroupCanaryApprovalDeployStageDetails": UpdateComputeInstanceGroupCanaryApprovalDeployStageDetails,
    "UpdateComputeInstanceGroupCanaryDeployStageDetails": UpdateComputeInstanceGroupCanaryDeployStageDetails,
    "UpdateComputeInstanceGroupCanaryTrafficShiftDeployStageDetails": UpdateComputeInstanceGroupCanaryTrafficShiftDeployStageDetails,
    "UpdateComputeInstanceGroupDeployEnvironmentDetails": UpdateComputeInstanceGroupDeployEnvironmentDetails,
    "UpdateComputeInstanceGroupDeployStageDetails": UpdateComputeInstanceGroupDeployStageDetails,
    "UpdateConnectionDetails": UpdateConnectionDetails,
    "UpdateDeliverArtifactStageDetails": UpdateDeliverArtifactStageDetails,
    "UpdateDeployArtifactDetails": UpdateDeployArtifactDetails,
    "UpdateDeployEnvironmentDetails": UpdateDeployEnvironmentDetails,
    "UpdateDeployPipelineDeploymentDetails": UpdateDeployPipelineDeploymentDetails,
    "UpdateDeployPipelineDetails": UpdateDeployPipelineDetails,
    "UpdateDeployPipelineRedeploymentDetails": UpdateDeployPipelineRedeploymentDetails,
    "UpdateDeployStageDetails": UpdateDeployStageDetails,
    "UpdateDeploymentDetails": UpdateDeploymentDetails,
    "UpdateDevopsCodeRepositoryTriggerDetails": UpdateDevopsCodeRepositoryTriggerDetails,
    "UpdateFunctionDeployEnvironmentDetails": UpdateFunctionDeployEnvironmentDetails,
    "UpdateFunctionDeployStageDetails": UpdateFunctionDeployStageDetails,
    "UpdateGithubAccessTokenConnectionDetails": UpdateGithubAccessTokenConnectionDetails,
    "UpdateGithubTriggerDetails": UpdateGithubTriggerDetails,
    "UpdateGitlabAccessTokenConnectionDetails": UpdateGitlabAccessTokenConnectionDetails,
    "UpdateGitlabTriggerDetails": UpdateGitlabTriggerDetails,
    "UpdateInvokeFunctionDeployStageDetails": UpdateInvokeFunctionDeployStageDetails,
    "UpdateLoadBalancerTrafficShiftDeployStageDetails": UpdateLoadBalancerTrafficShiftDeployStageDetails,
    "UpdateManualApprovalDeployStageDetails": UpdateManualApprovalDeployStageDetails,
    "UpdateOkeBlueGreenDeployStageDetails": UpdateOkeBlueGreenDeployStageDetails,
    "UpdateOkeBlueGreenTrafficShiftDeployStageDetails": UpdateOkeBlueGreenTrafficShiftDeployStageDetails,
    "UpdateOkeCanaryApprovalDeployStageDetails": UpdateOkeCanaryApprovalDeployStageDetails,
    "UpdateOkeCanaryDeployStageDetails": UpdateOkeCanaryDeployStageDetails,
    "UpdateOkeCanaryTrafficShiftDeployStageDetails": UpdateOkeCanaryTrafficShiftDeployStageDetails,
    "UpdateOkeClusterDeployEnvironmentDetails": UpdateOkeClusterDeployEnvironmentDetails,
    "UpdateOkeDeployStageDetails": UpdateOkeDeployStageDetails,
    "UpdateOkeHelmChartDeployStageDetails": UpdateOkeHelmChartDeployStageDetails,
    "UpdateProjectDetails": UpdateProjectDetails,
    "UpdateRepositoryDetails": UpdateRepositoryDetails,
    "UpdateSingleDeployStageDeploymentDetails": UpdateSingleDeployStageDeploymentDetails,
    "UpdateSingleDeployStageRedeploymentDetails": UpdateSingleDeployStageRedeploymentDetails,
    "UpdateTriggerDeploymentStageDetails": UpdateTriggerDeploymentStageDetails,
    "UpdateTriggerDetails": UpdateTriggerDetails,
    "UpdateWaitCriteriaDetails": UpdateWaitCriteriaDetails,
    "UpdateWaitDeployStageDetails": UpdateWaitDeployStageDetails,
    "UpdateWaitStageDetails": UpdateWaitStageDetails,
    "VulnerabilityAuditSummary": VulnerabilityAuditSummary,
    "VulnerabilityAuditSummaryCollection": VulnerabilityAuditSummaryCollection,
    "WaitCriteria": WaitCriteria,
    "WaitCriteriaSummary": WaitCriteriaSummary,
    "WaitDeployStage": WaitDeployStage,
    "WaitDeployStageExecutionProgress": WaitDeployStageExecutionProgress,
    "WaitDeployStageSummary": WaitDeployStageSummary,
    "WaitStage": WaitStage,
    "WaitStageRunProgress": WaitStageRunProgress,
    "WaitStageSummary": WaitStageSummary,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Certificate(object):
    """
    The details of the certificate. This object does not contain the certificate contents.
    """

    #: A constant which can be used with the lifecycle_state property of a Certificate.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Certificate.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Certificate.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Certificate.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Certificate.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Certificate.
    #: This constant has a value of "SCHEDULING_DELETION"
    LIFECYCLE_STATE_SCHEDULING_DELETION = "SCHEDULING_DELETION"

    #: A constant which can be used with the lifecycle_state property of a Certificate.
    #: This constant has a value of "PENDING_DELETION"
    LIFECYCLE_STATE_PENDING_DELETION = "PENDING_DELETION"

    #: A constant which can be used with the lifecycle_state property of a Certificate.
    #: This constant has a value of "CANCELLING_DELETION"
    LIFECYCLE_STATE_CANCELLING_DELETION = "CANCELLING_DELETION"

    #: A constant which can be used with the lifecycle_state property of a Certificate.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the config_type property of a Certificate.
    #: This constant has a value of "ISSUED_BY_INTERNAL_CA"
    CONFIG_TYPE_ISSUED_BY_INTERNAL_CA = "ISSUED_BY_INTERNAL_CA"

    #: A constant which can be used with the config_type property of a Certificate.
    #: This constant has a value of "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA"
    CONFIG_TYPE_MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA = "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA"

    #: A constant which can be used with the config_type property of a Certificate.
    #: This constant has a value of "IMPORTED"
    CONFIG_TYPE_IMPORTED = "IMPORTED"

    #: A constant which can be used with the key_algorithm property of a Certificate.
    #: This constant has a value of "RSA2048"
    KEY_ALGORITHM_RSA2048 = "RSA2048"

    #: A constant which can be used with the key_algorithm property of a Certificate.
    #: This constant has a value of "RSA4096"
    KEY_ALGORITHM_RSA4096 = "RSA4096"

    #: A constant which can be used with the key_algorithm property of a Certificate.
    #: This constant has a value of "ECDSA_P256"
    KEY_ALGORITHM_ECDSA_P256 = "ECDSA_P256"

    #: A constant which can be used with the key_algorithm property of a Certificate.
    #: This constant has a value of "ECDSA_P384"
    KEY_ALGORITHM_ECDSA_P384 = "ECDSA_P384"

    #: A constant which can be used with the signature_algorithm property of a Certificate.
    #: This constant has a value of "SHA256_WITH_RSA"
    SIGNATURE_ALGORITHM_SHA256_WITH_RSA = "SHA256_WITH_RSA"

    #: A constant which can be used with the signature_algorithm property of a Certificate.
    #: This constant has a value of "SHA384_WITH_RSA"
    SIGNATURE_ALGORITHM_SHA384_WITH_RSA = "SHA384_WITH_RSA"

    #: A constant which can be used with the signature_algorithm property of a Certificate.
    #: This constant has a value of "SHA512_WITH_RSA"
    SIGNATURE_ALGORITHM_SHA512_WITH_RSA = "SHA512_WITH_RSA"

    #: A constant which can be used with the signature_algorithm property of a Certificate.
    #: This constant has a value of "SHA256_WITH_ECDSA"
    SIGNATURE_ALGORITHM_SHA256_WITH_ECDSA = "SHA256_WITH_ECDSA"

    #: A constant which can be used with the signature_algorithm property of a Certificate.
    #: This constant has a value of "SHA384_WITH_ECDSA"
    SIGNATURE_ALGORITHM_SHA384_WITH_ECDSA = "SHA384_WITH_ECDSA"

    #: A constant which can be used with the signature_algorithm property of a Certificate.
    #: This constant has a value of "SHA512_WITH_ECDSA"
    SIGNATURE_ALGORITHM_SHA512_WITH_ECDSA = "SHA512_WITH_ECDSA"

    #: A constant which can be used with the certificate_profile_type property of a Certificate.
    #: This constant has a value of "TLS_SERVER_OR_CLIENT"
    CERTIFICATE_PROFILE_TYPE_TLS_SERVER_OR_CLIENT = "TLS_SERVER_OR_CLIENT"

    #: A constant which can be used with the certificate_profile_type property of a Certificate.
    #: This constant has a value of "TLS_SERVER"
    CERTIFICATE_PROFILE_TYPE_TLS_SERVER = "TLS_SERVER"

    #: A constant which can be used with the certificate_profile_type property of a Certificate.
    #: This constant has a value of "TLS_CLIENT"
    CERTIFICATE_PROFILE_TYPE_TLS_CLIENT = "TLS_CLIENT"

    #: A constant which can be used with the certificate_profile_type property of a Certificate.
    #: This constant has a value of "TLS_CODE_SIGN"
    CERTIFICATE_PROFILE_TYPE_TLS_CODE_SIGN = "TLS_CODE_SIGN"

    def __init__(self, **kwargs):
        """
        Initializes a new Certificate object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Certificate.
        :type id: str

        :param issuer_certificate_authority_id:
            The value to assign to the issuer_certificate_authority_id property of this Certificate.
        :type issuer_certificate_authority_id: str

        :param name:
            The value to assign to the name property of this Certificate.
        :type name: str

        :param description:
            The value to assign to the description property of this Certificate.
        :type description: str

        :param certificate_rules:
            The value to assign to the certificate_rules property of this Certificate.
        :type certificate_rules: list[oci.certificates_management.models.CertificateRule]

        :param time_created:
            The value to assign to the time_created property of this Certificate.
        :type time_created: datetime

        :param time_of_deletion:
            The value to assign to the time_of_deletion property of this Certificate.
        :type time_of_deletion: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Certificate.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "SCHEDULING_DELETION", "PENDING_DELETION", "CANCELLING_DELETION", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this Certificate.
        :type lifecycle_details: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Certificate.
        :type compartment_id: str

        :param current_version:
            The value to assign to the current_version property of this Certificate.
        :type current_version: oci.certificates_management.models.CertificateVersionSummary

        :param subject:
            The value to assign to the subject property of this Certificate.
        :type subject: oci.certificates_management.models.CertificateSubject

        :param certificate_revocation_list_details:
            The value to assign to the certificate_revocation_list_details property of this Certificate.
        :type certificate_revocation_list_details: oci.certificates_management.models.CertificateRevocationListDetails

        :param config_type:
            The value to assign to the config_type property of this Certificate.
            Allowed values for this property are: "ISSUED_BY_INTERNAL_CA", "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA", "IMPORTED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type config_type: str

        :param key_algorithm:
            The value to assign to the key_algorithm property of this Certificate.
            Allowed values for this property are: "RSA2048", "RSA4096", "ECDSA_P256", "ECDSA_P384", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type key_algorithm: str

        :param signature_algorithm:
            The value to assign to the signature_algorithm property of this Certificate.
            Allowed values for this property are: "SHA256_WITH_RSA", "SHA384_WITH_RSA", "SHA512_WITH_RSA", "SHA256_WITH_ECDSA", "SHA384_WITH_ECDSA", "SHA512_WITH_ECDSA", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type signature_algorithm: str

        :param certificate_profile_type:
            The value to assign to the certificate_profile_type property of this Certificate.
            Allowed values for this property are: "TLS_SERVER_OR_CLIENT", "TLS_SERVER", "TLS_CLIENT", "TLS_CODE_SIGN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type certificate_profile_type: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Certificate.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Certificate.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'issuer_certificate_authority_id': 'str',
            'name': 'str',
            'description': 'str',
            'certificate_rules': 'list[CertificateRule]',
            'time_created': 'datetime',
            'time_of_deletion': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'compartment_id': 'str',
            'current_version': 'CertificateVersionSummary',
            'subject': 'CertificateSubject',
            'certificate_revocation_list_details': 'CertificateRevocationListDetails',
            'config_type': 'str',
            'key_algorithm': 'str',
            'signature_algorithm': 'str',
            'certificate_profile_type': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'issuer_certificate_authority_id': 'issuerCertificateAuthorityId',
            'name': 'name',
            'description': 'description',
            'certificate_rules': 'certificateRules',
            'time_created': 'timeCreated',
            'time_of_deletion': 'timeOfDeletion',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'compartment_id': 'compartmentId',
            'current_version': 'currentVersion',
            'subject': 'subject',
            'certificate_revocation_list_details': 'certificateRevocationListDetails',
            'config_type': 'configType',
            'key_algorithm': 'keyAlgorithm',
            'signature_algorithm': 'signatureAlgorithm',
            'certificate_profile_type': 'certificateProfileType',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._issuer_certificate_authority_id = None
        self._name = None
        self._description = None
        self._certificate_rules = None
        self._time_created = None
        self._time_of_deletion = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._compartment_id = None
        self._current_version = None
        self._subject = None
        self._certificate_revocation_list_details = None
        self._config_type = None
        self._key_algorithm = None
        self._signature_algorithm = None
        self._certificate_profile_type = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Certificate.
        The OCID of the certificate.


        :return: The id of this Certificate.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Certificate.
        The OCID of the certificate.


        :param id: The id of this Certificate.
        :type: str
        """
        self._id = id

    @property
    def issuer_certificate_authority_id(self):
        """
        Gets the issuer_certificate_authority_id of this Certificate.
        The OCID of the certificate authority (CA) that issued the certificate.


        :return: The issuer_certificate_authority_id of this Certificate.
        :rtype: str
        """
        return self._issuer_certificate_authority_id

    @issuer_certificate_authority_id.setter
    def issuer_certificate_authority_id(self, issuer_certificate_authority_id):
        """
        Sets the issuer_certificate_authority_id of this Certificate.
        The OCID of the certificate authority (CA) that issued the certificate.


        :param issuer_certificate_authority_id: The issuer_certificate_authority_id of this Certificate.
        :type: str
        """
        self._issuer_certificate_authority_id = issuer_certificate_authority_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Certificate.
        A user-friendly name for the certificate. Names are unique within a compartment. Avoid entering confidential information. Valid characters are uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        :return: The name of this Certificate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Certificate.
        A user-friendly name for the certificate. Names are unique within a compartment. Avoid entering confidential information. Valid characters are uppercase or lowercase letters, numbers, hyphens, underscores, and periods.


        :param name: The name of this Certificate.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Certificate.
        A brief description of the certificate. Avoid entering confidential information.


        :return: The description of this Certificate.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Certificate.
        A brief description of the certificate. Avoid entering confidential information.


        :param description: The description of this Certificate.
        :type: str
        """
        self._description = description

    @property
    def certificate_rules(self):
        """
        Gets the certificate_rules of this Certificate.
        A list of rules that control how the certificate is used and managed.


        :return: The certificate_rules of this Certificate.
        :rtype: list[oci.certificates_management.models.CertificateRule]
        """
        return self._certificate_rules

    @certificate_rules.setter
    def certificate_rules(self, certificate_rules):
        """
        Sets the certificate_rules of this Certificate.
        A list of rules that control how the certificate is used and managed.


        :param certificate_rules: The certificate_rules of this Certificate.
        :type: list[oci.certificates_management.models.CertificateRule]
        """
        self._certificate_rules = certificate_rules

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Certificate.
        A property indicating when the certificate was created, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Certificate.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Certificate.
        A property indicating when the certificate was created, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Certificate.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_of_deletion(self):
        """
        Gets the time_of_deletion of this Certificate.
        An optional property indicating when to delete the certificate version, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_deletion of this Certificate.
        :rtype: datetime
        """
        return self._time_of_deletion

    @time_of_deletion.setter
    def time_of_deletion(self, time_of_deletion):
        """
        Sets the time_of_deletion of this Certificate.
        An optional property indicating when to delete the certificate version, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_deletion: The time_of_deletion of this Certificate.
        :type: datetime
        """
        self._time_of_deletion = time_of_deletion

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Certificate.
        The current lifecycle state of the certificate.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "SCHEDULING_DELETION", "PENDING_DELETION", "CANCELLING_DELETION", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Certificate.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Certificate.
        The current lifecycle state of the certificate.


        :param lifecycle_state: The lifecycle_state of this Certificate.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "SCHEDULING_DELETION", "PENDING_DELETION", "CANCELLING_DELETION", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this Certificate.
        Additional information about the current lifecycle state of the certificate.


        :return: The lifecycle_details of this Certificate.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this Certificate.
        Additional information about the current lifecycle state of the certificate.


        :param lifecycle_details: The lifecycle_details of this Certificate.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Certificate.
        The OCID of the compartment where you want to create the certificate.


        :return: The compartment_id of this Certificate.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Certificate.
        The OCID of the compartment where you want to create the certificate.


        :param compartment_id: The compartment_id of this Certificate.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def current_version(self):
        """
        Gets the current_version of this Certificate.

        :return: The current_version of this Certificate.
        :rtype: oci.certificates_management.models.CertificateVersionSummary
        """
        return self._current_version

    @current_version.setter
    def current_version(self, current_version):
        """
        Sets the current_version of this Certificate.

        :param current_version: The current_version of this Certificate.
        :type: oci.certificates_management.models.CertificateVersionSummary
        """
        self._current_version = current_version

    @property
    def subject(self):
        """
        Gets the subject of this Certificate.

        :return: The subject of this Certificate.
        :rtype: oci.certificates_management.models.CertificateSubject
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this Certificate.

        :param subject: The subject of this Certificate.
        :type: oci.certificates_management.models.CertificateSubject
        """
        self._subject = subject

    @property
    def certificate_revocation_list_details(self):
        """
        Gets the certificate_revocation_list_details of this Certificate.

        :return: The certificate_revocation_list_details of this Certificate.
        :rtype: oci.certificates_management.models.CertificateRevocationListDetails
        """
        return self._certificate_revocation_list_details

    @certificate_revocation_list_details.setter
    def certificate_revocation_list_details(self, certificate_revocation_list_details):
        """
        Sets the certificate_revocation_list_details of this Certificate.

        :param certificate_revocation_list_details: The certificate_revocation_list_details of this Certificate.
        :type: oci.certificates_management.models.CertificateRevocationListDetails
        """
        self._certificate_revocation_list_details = certificate_revocation_list_details

    @property
    def config_type(self):
        """
        **[Required]** Gets the config_type of this Certificate.
        The origin of the certificate.

        Allowed values for this property are: "ISSUED_BY_INTERNAL_CA", "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA", "IMPORTED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The config_type of this Certificate.
        :rtype: str
        """
        return self._config_type

    @config_type.setter
    def config_type(self, config_type):
        """
        Sets the config_type of this Certificate.
        The origin of the certificate.


        :param config_type: The config_type of this Certificate.
        :type: str
        """
        allowed_values = ["ISSUED_BY_INTERNAL_CA", "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA", "IMPORTED"]
        if not value_allowed_none_or_none_sentinel(config_type, allowed_values):
            config_type = 'UNKNOWN_ENUM_VALUE'
        self._config_type = config_type

    @property
    def key_algorithm(self):
        """
        Gets the key_algorithm of this Certificate.
        The algorithm used to create key pairs.

        Allowed values for this property are: "RSA2048", "RSA4096", "ECDSA_P256", "ECDSA_P384", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The key_algorithm of this Certificate.
        :rtype: str
        """
        return self._key_algorithm

    @key_algorithm.setter
    def key_algorithm(self, key_algorithm):
        """
        Sets the key_algorithm of this Certificate.
        The algorithm used to create key pairs.


        :param key_algorithm: The key_algorithm of this Certificate.
        :type: str
        """
        allowed_values = ["RSA2048", "RSA4096", "ECDSA_P256", "ECDSA_P384"]
        if not value_allowed_none_or_none_sentinel(key_algorithm, allowed_values):
            key_algorithm = 'UNKNOWN_ENUM_VALUE'
        self._key_algorithm = key_algorithm

    @property
    def signature_algorithm(self):
        """
        Gets the signature_algorithm of this Certificate.
        The algorithm used to sign the public key certificate.

        Allowed values for this property are: "SHA256_WITH_RSA", "SHA384_WITH_RSA", "SHA512_WITH_RSA", "SHA256_WITH_ECDSA", "SHA384_WITH_ECDSA", "SHA512_WITH_ECDSA", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The signature_algorithm of this Certificate.
        :rtype: str
        """
        return self._signature_algorithm

    @signature_algorithm.setter
    def signature_algorithm(self, signature_algorithm):
        """
        Sets the signature_algorithm of this Certificate.
        The algorithm used to sign the public key certificate.


        :param signature_algorithm: The signature_algorithm of this Certificate.
        :type: str
        """
        allowed_values = ["SHA256_WITH_RSA", "SHA384_WITH_RSA", "SHA512_WITH_RSA", "SHA256_WITH_ECDSA", "SHA384_WITH_ECDSA", "SHA512_WITH_ECDSA"]
        if not value_allowed_none_or_none_sentinel(signature_algorithm, allowed_values):
            signature_algorithm = 'UNKNOWN_ENUM_VALUE'
        self._signature_algorithm = signature_algorithm

    @property
    def certificate_profile_type(self):
        """
        Gets the certificate_profile_type of this Certificate.
        The name of the profile used to create the certificate, which depends on the type of certificate you need.

        Allowed values for this property are: "TLS_SERVER_OR_CLIENT", "TLS_SERVER", "TLS_CLIENT", "TLS_CODE_SIGN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The certificate_profile_type of this Certificate.
        :rtype: str
        """
        return self._certificate_profile_type

    @certificate_profile_type.setter
    def certificate_profile_type(self, certificate_profile_type):
        """
        Sets the certificate_profile_type of this Certificate.
        The name of the profile used to create the certificate, which depends on the type of certificate you need.


        :param certificate_profile_type: The certificate_profile_type of this Certificate.
        :type: str
        """
        allowed_values = ["TLS_SERVER_OR_CLIENT", "TLS_SERVER", "TLS_CLIENT", "TLS_CODE_SIGN"]
        if not value_allowed_none_or_none_sentinel(certificate_profile_type, allowed_values):
            certificate_profile_type = 'UNKNOWN_ENUM_VALUE'
        self._certificate_profile_type = certificate_profile_type

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Certificate.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Certificate.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Certificate.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Certificate.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Certificate.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Certificate.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Certificate.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Certificate.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JWK(object):
    """
    JWK model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new JWK object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param n:
            The value to assign to the n property of this JWK.
        :type n: str

        :param e:
            The value to assign to the e property of this JWK.
        :type e: str

        :param kid:
            The value to assign to the kid property of this JWK.
        :type kid: str

        :param use:
            The value to assign to the use property of this JWK.
        :type use: str

        :param alg:
            The value to assign to the alg property of this JWK.
        :type alg: str

        :param kty:
            The value to assign to the kty property of this JWK.
        :type kty: str

        """
        self.swagger_types = {
            'n': 'str',
            'e': 'str',
            'kid': 'str',
            'use': 'str',
            'alg': 'str',
            'kty': 'str'
        }

        self.attribute_map = {
            'n': 'n',
            'e': 'e',
            'kid': 'kid',
            'use': 'use',
            'alg': 'alg',
            'kty': 'kty'
        }

        self._n = None
        self._e = None
        self._kid = None
        self._use = None
        self._alg = None
        self._kty = None

    @property
    def n(self):
        """
        **[Required]** Gets the n of this JWK.
        The modulus.


        :return: The n of this JWK.
        :rtype: str
        """
        return self._n

    @n.setter
    def n(self, n):
        """
        Sets the n of this JWK.
        The modulus.


        :param n: The n of this JWK.
        :type: str
        """
        self._n = n

    @property
    def e(self):
        """
        **[Required]** Gets the e of this JWK.
        The exponent.


        :return: The e of this JWK.
        :rtype: str
        """
        return self._e

    @e.setter
    def e(self, e):
        """
        Sets the e of this JWK.
        The exponent.


        :param e: The e of this JWK.
        :type: str
        """
        self._e = e

    @property
    def kid(self):
        """
        **[Required]** Gets the kid of this JWK.
        The key id.


        :return: The kid of this JWK.
        :rtype: str
        """
        return self._kid

    @kid.setter
    def kid(self, kid):
        """
        Sets the kid of this JWK.
        The key id.


        :param kid: The kid of this JWK.
        :type: str
        """
        self._kid = kid

    @property
    def use(self):
        """
        **[Required]** Gets the use of this JWK.
        The key use.


        :return: The use of this JWK.
        :rtype: str
        """
        return self._use

    @use.setter
    def use(self, use):
        """
        Sets the use of this JWK.
        The key use.


        :param use: The use of this JWK.
        :type: str
        """
        self._use = use

    @property
    def alg(self):
        """
        **[Required]** Gets the alg of this JWK.
        The algorithm.


        :return: The alg of this JWK.
        :rtype: str
        """
        return self._alg

    @alg.setter
    def alg(self, alg):
        """
        Sets the alg of this JWK.
        The algorithm.


        :param alg: The alg of this JWK.
        :type: str
        """
        self._alg = alg

    @property
    def kty(self):
        """
        **[Required]** Gets the kty of this JWK.
        The key type.


        :return: The kty of this JWK.
        :rtype: str
        """
        return self._kty

    @kty.setter
    def kty(self, kty):
        """
        Sets the kty of this JWK.
        The key type.


        :param kty: The kty of this JWK.
        :type: str
        """
        self._kty = kty

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TaskRunSummary(object):
    """
    The information about a task run.
    """

    #: A constant which can be used with the status property of a TaskRunSummary.
    #: This constant has a value of "NOT_STARTED"
    STATUS_NOT_STARTED = "NOT_STARTED"

    #: A constant which can be used with the status property of a TaskRunSummary.
    #: This constant has a value of "QUEUED"
    STATUS_QUEUED = "QUEUED"

    #: A constant which can be used with the status property of a TaskRunSummary.
    #: This constant has a value of "RUNNING"
    STATUS_RUNNING = "RUNNING"

    #: A constant which can be used with the status property of a TaskRunSummary.
    #: This constant has a value of "TERMINATING"
    STATUS_TERMINATING = "TERMINATING"

    #: A constant which can be used with the status property of a TaskRunSummary.
    #: This constant has a value of "TERMINATED"
    STATUS_TERMINATED = "TERMINATED"

    #: A constant which can be used with the status property of a TaskRunSummary.
    #: This constant has a value of "SUCCESS"
    STATUS_SUCCESS = "SUCCESS"

    #: A constant which can be used with the status property of a TaskRunSummary.
    #: This constant has a value of "ERROR"
    STATUS_ERROR = "ERROR"

    #: A constant which can be used with the task_type property of a TaskRunSummary.
    #: This constant has a value of "INTEGRATION_TASK"
    TASK_TYPE_INTEGRATION_TASK = "INTEGRATION_TASK"

    #: A constant which can be used with the task_type property of a TaskRunSummary.
    #: This constant has a value of "DATA_LOADER_TASK"
    TASK_TYPE_DATA_LOADER_TASK = "DATA_LOADER_TASK"

    #: A constant which can be used with the task_type property of a TaskRunSummary.
    #: This constant has a value of "PIPELINE_TASK"
    TASK_TYPE_PIPELINE_TASK = "PIPELINE_TASK"

    #: A constant which can be used with the task_type property of a TaskRunSummary.
    #: This constant has a value of "SQL_TASK"
    TASK_TYPE_SQL_TASK = "SQL_TASK"

    #: A constant which can be used with the task_type property of a TaskRunSummary.
    #: This constant has a value of "OCI_DATAFLOW_TASK"
    TASK_TYPE_OCI_DATAFLOW_TASK = "OCI_DATAFLOW_TASK"

    #: A constant which can be used with the task_type property of a TaskRunSummary.
    #: This constant has a value of "REST_TASK"
    TASK_TYPE_REST_TASK = "REST_TASK"

    #: A constant which can be used with the re_run_type property of a TaskRunSummary.
    #: This constant has a value of "BEGINNING"
    RE_RUN_TYPE_BEGINNING = "BEGINNING"

    #: A constant which can be used with the re_run_type property of a TaskRunSummary.
    #: This constant has a value of "FAILED"
    RE_RUN_TYPE_FAILED = "FAILED"

    #: A constant which can be used with the re_run_type property of a TaskRunSummary.
    #: This constant has a value of "STEP"
    RE_RUN_TYPE_STEP = "STEP"

    def __init__(self, **kwargs):
        """
        Initializes a new TaskRunSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this TaskRunSummary.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this TaskRunSummary.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this TaskRunSummary.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this TaskRunSummary.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this TaskRunSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this TaskRunSummary.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this TaskRunSummary.
        :type object_version: int

        :param status:
            The value to assign to the status property of this TaskRunSummary.
            Allowed values for this property are: "NOT_STARTED", "QUEUED", "RUNNING", "TERMINATING", "TERMINATED", "SUCCESS", "ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param start_time_millis:
            The value to assign to the start_time_millis property of this TaskRunSummary.
        :type start_time_millis: int

        :param end_time_millis:
            The value to assign to the end_time_millis property of this TaskRunSummary.
        :type end_time_millis: int

        :param last_updated:
            The value to assign to the last_updated property of this TaskRunSummary.
        :type last_updated: int

        :param records_written:
            The value to assign to the records_written property of this TaskRunSummary.
        :type records_written: int

        :param bytes_processed:
            The value to assign to the bytes_processed property of this TaskRunSummary.
        :type bytes_processed: int

        :param object_status:
            The value to assign to the object_status property of this TaskRunSummary.
        :type object_status: int

        :param task_type:
            The value to assign to the task_type property of this TaskRunSummary.
            Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type task_type: str

        :param identifier:
            The value to assign to the identifier property of this TaskRunSummary.
        :type identifier: str

        :param ref_task_run_id:
            The value to assign to the ref_task_run_id property of this TaskRunSummary.
        :type ref_task_run_id: str

        :param re_run_type:
            The value to assign to the re_run_type property of this TaskRunSummary.
            Allowed values for this property are: "BEGINNING", "FAILED", "STEP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type re_run_type: str

        :param step_id:
            The value to assign to the step_id property of this TaskRunSummary.
        :type step_id: str

        :param inputs:
            The value to assign to the inputs property of this TaskRunSummary.
        :type inputs: dict(str, ParameterValue)

        :param metadata:
            The value to assign to the metadata property of this TaskRunSummary.
        :type metadata: oci.data_integration.models.ObjectMetadata

        """
        self.swagger_types = {
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'status': 'str',
            'start_time_millis': 'int',
            'end_time_millis': 'int',
            'last_updated': 'int',
            'records_written': 'int',
            'bytes_processed': 'int',
            'object_status': 'int',
            'task_type': 'str',
            'identifier': 'str',
            'ref_task_run_id': 'str',
            're_run_type': 'str',
            'step_id': 'str',
            'inputs': 'dict(str, ParameterValue)',
            'metadata': 'ObjectMetadata'
        }

        self.attribute_map = {
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'status': 'status',
            'start_time_millis': 'startTimeMillis',
            'end_time_millis': 'endTimeMillis',
            'last_updated': 'lastUpdated',
            'records_written': 'recordsWritten',
            'bytes_processed': 'bytesProcessed',
            'object_status': 'objectStatus',
            'task_type': 'taskType',
            'identifier': 'identifier',
            'ref_task_run_id': 'refTaskRunId',
            're_run_type': 'reRunType',
            'step_id': 'stepId',
            'inputs': 'inputs',
            'metadata': 'metadata'
        }

        self._key = None
        self._model_type = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._status = None
        self._start_time_millis = None
        self._end_time_millis = None
        self._last_updated = None
        self._records_written = None
        self._bytes_processed = None
        self._object_status = None
        self._task_type = None
        self._identifier = None
        self._ref_task_run_id = None
        self._re_run_type = None
        self._step_id = None
        self._inputs = None
        self._metadata = None

    @property
    def key(self):
        """
        Gets the key of this TaskRunSummary.
        The object key.


        :return: The key of this TaskRunSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this TaskRunSummary.
        The object key.


        :param key: The key of this TaskRunSummary.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this TaskRunSummary.
        The object type.


        :return: The model_type of this TaskRunSummary.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this TaskRunSummary.
        The object type.


        :param model_type: The model_type of this TaskRunSummary.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this TaskRunSummary.
        The object's model version.


        :return: The model_version of this TaskRunSummary.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this TaskRunSummary.
        The object's model version.


        :param model_version: The model_version of this TaskRunSummary.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this TaskRunSummary.

        :return: The parent_ref of this TaskRunSummary.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this TaskRunSummary.

        :param parent_ref: The parent_ref of this TaskRunSummary.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this TaskRunSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this TaskRunSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TaskRunSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this TaskRunSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this TaskRunSummary.
        Detailed description for the object.


        :return: The description of this TaskRunSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TaskRunSummary.
        Detailed description for the object.


        :param description: The description of this TaskRunSummary.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this TaskRunSummary.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this TaskRunSummary.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this TaskRunSummary.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this TaskRunSummary.
        :type: int
        """
        self._object_version = object_version

    @property
    def status(self):
        """
        Gets the status of this TaskRunSummary.
        status

        Allowed values for this property are: "NOT_STARTED", "QUEUED", "RUNNING", "TERMINATING", "TERMINATED", "SUCCESS", "ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this TaskRunSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this TaskRunSummary.
        status


        :param status: The status of this TaskRunSummary.
        :type: str
        """
        allowed_values = ["NOT_STARTED", "QUEUED", "RUNNING", "TERMINATING", "TERMINATED", "SUCCESS", "ERROR"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def start_time_millis(self):
        """
        Gets the start_time_millis of this TaskRunSummary.
        The task run start time.


        :return: The start_time_millis of this TaskRunSummary.
        :rtype: int
        """
        return self._start_time_millis

    @start_time_millis.setter
    def start_time_millis(self, start_time_millis):
        """
        Sets the start_time_millis of this TaskRunSummary.
        The task run start time.


        :param start_time_millis: The start_time_millis of this TaskRunSummary.
        :type: int
        """
        self._start_time_millis = start_time_millis

    @property
    def end_time_millis(self):
        """
        Gets the end_time_millis of this TaskRunSummary.
        The task run end time.


        :return: The end_time_millis of this TaskRunSummary.
        :rtype: int
        """
        return self._end_time_millis

    @end_time_millis.setter
    def end_time_millis(self, end_time_millis):
        """
        Sets the end_time_millis of this TaskRunSummary.
        The task run end time.


        :param end_time_millis: The end_time_millis of this TaskRunSummary.
        :type: int
        """
        self._end_time_millis = end_time_millis

    @property
    def last_updated(self):
        """
        Gets the last_updated of this TaskRunSummary.
        The date and time the task run was last updated.


        :return: The last_updated of this TaskRunSummary.
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """
        Sets the last_updated of this TaskRunSummary.
        The date and time the task run was last updated.


        :param last_updated: The last_updated of this TaskRunSummary.
        :type: int
        """
        self._last_updated = last_updated

    @property
    def records_written(self):
        """
        Gets the records_written of this TaskRunSummary.
        Number of records processed in task run.


        :return: The records_written of this TaskRunSummary.
        :rtype: int
        """
        return self._records_written

    @records_written.setter
    def records_written(self, records_written):
        """
        Sets the records_written of this TaskRunSummary.
        Number of records processed in task run.


        :param records_written: The records_written of this TaskRunSummary.
        :type: int
        """
        self._records_written = records_written

    @property
    def bytes_processed(self):
        """
        Gets the bytes_processed of this TaskRunSummary.
        Number of bytes processed in task run.


        :return: The bytes_processed of this TaskRunSummary.
        :rtype: int
        """
        return self._bytes_processed

    @bytes_processed.setter
    def bytes_processed(self, bytes_processed):
        """
        Sets the bytes_processed of this TaskRunSummary.
        Number of bytes processed in task run.


        :param bytes_processed: The bytes_processed of this TaskRunSummary.
        :type: int
        """
        self._bytes_processed = bytes_processed

    @property
    def object_status(self):
        """
        Gets the object_status of this TaskRunSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this TaskRunSummary.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this TaskRunSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this TaskRunSummary.
        :type: int
        """
        self._object_status = object_status

    @property
    def task_type(self):
        """
        Gets the task_type of this TaskRunSummary.
        The type of the task for the run.

        Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The task_type of this TaskRunSummary.
        :rtype: str
        """
        return self._task_type

    @task_type.setter
    def task_type(self, task_type):
        """
        Sets the task_type of this TaskRunSummary.
        The type of the task for the run.


        :param task_type: The task_type of this TaskRunSummary.
        :type: str
        """
        allowed_values = ["INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK"]
        if not value_allowed_none_or_none_sentinel(task_type, allowed_values):
            task_type = 'UNKNOWN_ENUM_VALUE'
        self._task_type = task_type

    @property
    def identifier(self):
        """
        Gets the identifier of this TaskRunSummary.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this TaskRunSummary.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this TaskRunSummary.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this TaskRunSummary.
        :type: str
        """
        self._identifier = identifier

    @property
    def ref_task_run_id(self):
        """
        Gets the ref_task_run_id of this TaskRunSummary.
        Reference Task Run Id to be used for re-run


        :return: The ref_task_run_id of this TaskRunSummary.
        :rtype: str
        """
        return self._ref_task_run_id

    @ref_task_run_id.setter
    def ref_task_run_id(self, ref_task_run_id):
        """
        Sets the ref_task_run_id of this TaskRunSummary.
        Reference Task Run Id to be used for re-run


        :param ref_task_run_id: The ref_task_run_id of this TaskRunSummary.
        :type: str
        """
        self._ref_task_run_id = ref_task_run_id

    @property
    def re_run_type(self):
        """
        Gets the re_run_type of this TaskRunSummary.
        Supported re-run types

        Allowed values for this property are: "BEGINNING", "FAILED", "STEP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The re_run_type of this TaskRunSummary.
        :rtype: str
        """
        return self._re_run_type

    @re_run_type.setter
    def re_run_type(self, re_run_type):
        """
        Sets the re_run_type of this TaskRunSummary.
        Supported re-run types


        :param re_run_type: The re_run_type of this TaskRunSummary.
        :type: str
        """
        allowed_values = ["BEGINNING", "FAILED", "STEP"]
        if not value_allowed_none_or_none_sentinel(re_run_type, allowed_values):
            re_run_type = 'UNKNOWN_ENUM_VALUE'
        self._re_run_type = re_run_type

    @property
    def step_id(self):
        """
        Gets the step_id of this TaskRunSummary.
        Step Id for running from a certain step.


        :return: The step_id of this TaskRunSummary.
        :rtype: str
        """
        return self._step_id

    @step_id.setter
    def step_id(self, step_id):
        """
        Sets the step_id of this TaskRunSummary.
        Step Id for running from a certain step.


        :param step_id: The step_id of this TaskRunSummary.
        :type: str
        """
        self._step_id = step_id

    @property
    def inputs(self):
        """
        Gets the inputs of this TaskRunSummary.
        A map of the configuration provider input bindings of the run.


        :return: The inputs of this TaskRunSummary.
        :rtype: dict(str, ParameterValue)
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """
        Sets the inputs of this TaskRunSummary.
        A map of the configuration provider input bindings of the run.


        :param inputs: The inputs of this TaskRunSummary.
        :type: dict(str, ParameterValue)
        """
        self._inputs = inputs

    @property
    def metadata(self):
        """
        Gets the metadata of this TaskRunSummary.

        :return: The metadata of this TaskRunSummary.
        :rtype: oci.data_integration.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this TaskRunSummary.

        :param metadata: The metadata of this TaskRunSummary.
        :type: oci.data_integration.models.ObjectMetadata
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
